@@ -9,7 +9,7 @@
 //
 /**@name command.cpp - Give units a command. */
 //
-//      (c) Copyright 1998-2005 by Lutz Sammer and Jimmy Salmon
+//      (c) Copyright 1998-2007 by Lutz Sammer and Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: command.cpp 8550 2007-02-10 12:33:10Z feb $
+//      $Id: command.cpp 8749 2007-04-14 05:12:11Z jim4 $
 
 //@{
 
@@ -68,7 +68,7 @@ static void ReleaseOrder(COrder *order)
 }
 
 /**
-**  Release all orders of an unit.
+**  Release all orders of a unit.
 **
 **  @param unit  Pointer to unit.
 */
@@ -134,6 +134,9 @@ static void RemoveOrder(CUnit *unit, int order)
 	if (unit->OrderCount > 1) {
 		unit->Orders.pop_back();
 		--unit->OrderCount;
+		if (order == 0) {
+			unit->SubAction = 0;
+		}
 	} else {
 		Assert(i == 0);
 		unit->Orders[0]->Init();
@@ -497,7 +500,7 @@ void CommandAttackGround(CUnit *unit, int x, int y, int flush)
 }
 
 /**
-**  Let an unit patrol from current to new position
+**  Let a unit patrol from current to new position
 **
 **  FIXME: want to support patroling between units.
 **
@@ -664,7 +667,7 @@ void CommandBuildBuilding(CUnit *unit, int x, int y,
 }
 
 /**
-**  Cancel the building construction, or kill an unit.
+**  Cancel the building construction, or kill a unit.
 **
 **  @param unit  pointer to unit.
 */
@@ -722,49 +725,7 @@ void CommandResource(CUnit *unit, CUnit *dest, int flush)
 }
 
 /**
-**  Let unit returning goods.
-**
-**  @param unit   pointer to unit.
-**  @param goal   bring goods to this depot.
-**  @param flush  if true, flush command queue.
-*/
-void CommandReturnGoods(CUnit *unit, CUnit *goal, int flush)
-{
-	COrder *order;
-
-	//
-	// Check if unit is still valid and Goal still alive? (NETWORK!)
-	//
-	if (!unit->Removed && unit->Orders[0]->Action != UnitActionDie) {
-		if (!unit->Type->Building && !unit->Type->Harvester && !unit->ResourcesHeld) {
-			ClearSavedAction(unit);
-			return;
-		}
-
-		if (unit->Type->Building) {
-			// FIXME: should find a better way for pending orders.
-			order = &unit->NewOrder;
-			ReleaseOrder(order);
-		} else if (!(order = GetNextOrder(unit, flush))) {
-			return;
-		}
-		order->Init();
-
-		order->Action = UnitActionReturnGoods;
-		//
-		// Destination could be killed. NETWORK!
-		//
-		if (goal && !goal->Destroyed) {
-			order->Goal = goal;
-			goal->RefsIncrease();
-		}
-		order->Range = 1;
-	}
-	ClearSavedAction(unit);
-}
-
-/**
-**  Building starts training an unit.
+**  Building starts training a unit.
 **
 **  @param unit   pointer to unit.
 **  @param type   unit type to train.
@@ -782,18 +743,10 @@ void CommandTrainUnit(CUnit *unit, CUnitType *type, int flush)
 		// Check if enough resources remains? (NETWORK!)
 		// FIXME: wrong if append to message queue!!!
 		//
-		if (unit->Player->CheckLimits(type) < 0 ||
-				unit->Player->CheckUnitType(type)) {
+		if (unit->Player->CheckLimits(type) < 0 ) {
 			return;
 		}
 
-		//
-		// Not already training?
-		//
-		if (!EnableTrainingQueue && unit->Orders[0]->Action == UnitActionTrain) {
-			DebugPrint("Unit queue full!\n");
-			return;
-		}
 		if (!(order = GetNextOrder(unit, 0))) {
 			return;
 		}
@@ -801,14 +754,12 @@ void CommandTrainUnit(CUnit *unit, CUnitType *type, int flush)
 
 		order->Action = UnitActionTrain;
 		order->Type = type;
-		// FIXME: if you give quick an other order, the resources are lost!
-		unit->Player->SubUnitType(type);
 	}
 	ClearSavedAction(unit);
 }
 
 /**
-**  Cancel the training of an unit.
+**  Cancel the training of a unit.
 **
 **  @param unit  pointer to unit.
 **  @param slot  slot number to cancel.
@@ -826,11 +777,12 @@ void CommandCancelTraining(CUnit *unit, int slot, const CUnitType *type)
 	//
 
 	if (slot == -1) {
+		if (unit->Orders[0]->Action == UnitActionTrain) {
+			unit->Player->RemoveFromUnitsConsumingResources(unit);
+		}
+
 		// Cancel All training
 		while (unit->Orders[0]->Action == UnitActionTrain) {
-			unit->Player->AddCostsFactor(
-				unit->Orders[0]->Type->Stats[unit->Player->Index].Costs,
-				CancelTrainingCostsFactor);
 			RemoveOrder(unit, 0);
 		}
 		unit->Data.Train.Ticks = 0;
@@ -852,13 +804,9 @@ void CommandCancelTraining(CUnit *unit, int slot, const CUnitType *type)
 
 		DebugPrint("Cancel training\n");
 
-		unit->Player->AddCostsFactor(
-			unit->Orders[slot]->Type->Stats[unit->Player->Index].Costs,
-			CancelTrainingCostsFactor);
-
-	
 		if (!slot) { // Canceled in work slot
 			unit->Data.Train.Ticks = 0;
+			unit->Player->RemoveFromUnitsConsumingResources(unit);
 		}
 		RemoveOrder(unit, slot);
 
@@ -871,185 +819,6 @@ void CommandCancelTraining(CUnit *unit, int slot, const CUnitType *type)
 	}
 }
 
-/**
-**  Building starts upgrading to.
-**
-**  @param unit   pointer to unit.
-**  @param type   upgrade to type
-**  @param flush  if true, flush command queue.
-*/
-void CommandUpgradeTo(CUnit *unit, CUnitType *type, int flush)
-{
-	COrder *order;
-
-	//
-	// Check if unit is still valid and Goal still alive? (NETWORK!)
-	//
-	if (!unit->Removed && unit->Orders[0]->Action != UnitActionDie) {
-		//
-		// Check if enough resources remains? (NETWORK!)
-		//
-		if (unit->Player->CheckUnitType(type)) {
-			return;
-		}
-
-		if (!flush) {
-			DebugPrint("FIXME: must support order queing!!");
-		}
-		if (!(order = GetNextOrder(unit, flush))) {
-			return;
-		}
-		order->Init();
-
-		// FIXME: if you give quick an other order, the resources are lost!
-		unit->Player->SubUnitType(type);
-
-		order->Action = UnitActionUpgradeTo;
-		order->Type = type;
-	}
-	ClearSavedAction(unit);
-}
-
-/**
-**  Immediate transforming unit into type.
-**
-**  @param unit   pointer to unit.
-**  @param type   upgrade to type
-*/
-void CommandTransformIntoType(CUnit *unit, CUnitType *type)
-{
-	COrder *order;
-
-	Assert(unit->CriticalOrder.Action == UnitActionStill);
-	order = &unit->CriticalOrder;
-	order->Init();
-
-	order->Action = UnitActionTransformInto;
-	order->Type = type;
-}
-
-/**
-**  Cancel building upgrading to.
-**
-**  @param unit  pointer to unit.
-*/
-void CommandCancelUpgradeTo(CUnit *unit)
-{
-	ReleaseOrders(unit); // empty command queue
-
-	//
-	// Check if unit is still upgrading? (NETWORK!)
-	//
-	if (unit->Orders[0]->Action == UnitActionUpgradeTo) {
-
-		unit->Player->AddCostsFactor(
-			unit->Orders[0]->Type->Stats[unit->Player->Index].Costs,
-			CancelUpgradeCostsFactor);
-
-		unit->Orders[0]->Init();
-
-		unit->Orders[0]->Action = UnitActionStill;
-
-		unit->SubAction = 0;
-
-		//
-		// Update interface.
-		//
-		if (unit->Player == ThisPlayer && unit->Selected) {
-			SelectedUnitChanged();
-		}
-	}
-	ClearSavedAction(unit);
-}
-
-/**
-**  Building starts researching.
-**
-**  @param unit   pointer to unit.
-**  @param what   what to research.
-**  @param flush  if true, flush command queue.
-*/
-void CommandResearch(CUnit *unit, CUpgrade *what, int flush)
-{
-	COrder *order;
-
-	//
-	// Check if unit is still valid and Goal still alive? (NETWORK!)
-	//
-	if (!unit->Removed && unit->Orders[0]->Action != UnitActionDie) {
-		//
-		// Check if enough resources remains? (NETWORK!)
-		//
-		if (unit->Player->CheckCosts(what->Costs)) {
-			return;
-		}
-
-		if (!flush) {
-			DebugPrint("FIXME: must support order queing!!");
-		} else {
-			if (unit->Orders[0]->Action == UnitActionResearch) {
-				const CUpgrade *upgrade;
-
-				// Cancel current research
-				upgrade = unit->Data.Research.Upgrade;
-				unit->Player->UpgradeTimers.Upgrades[upgrade->ID] = 0;
-				unit->Player->AddCostsFactor(upgrade->Costs,
-					CancelResearchCostsFactor);
-				unit->SubAction = 0;
-			}
-		}
-
-		if (!(order = GetNextOrder(unit, flush))) {
-			return;
-		}
-		order->Init();
-
-		// FIXME: if you give quick an other order, the resources are lost!
-		unit->Player->SubCosts(what->Costs);
-
-		order->Action = UnitActionResearch;
-		order->X = order->Y = -1;
-		order->Arg1.Upgrade = what;
-	}
-	ClearSavedAction(unit);
-}
-
-/**
-**  Cancel Building researching.
-**
-**  @param unit  Pointer to unit.
-*/
-void CommandCancelResearch(CUnit *unit)
-{
-	ReleaseOrders(unit); // empty command queue
-
-	//
-	// Check if unit is still researching? (NETWORK!)
-	//
-	if (unit->Orders[0]->Action == UnitActionResearch) {
-		const CUpgrade *upgrade;
-
-		upgrade = unit->Data.Research.Upgrade;
-		unit->Player->UpgradeTimers.Upgrades[upgrade->ID] = 0;
-
-		unit->Player->AddCostsFactor(upgrade->Costs,
-			CancelResearchCostsFactor);
-		unit->Orders[0]->Init();
-
-		unit->Orders[0]->Action = UnitActionStill;
-
-		unit->SubAction = 0;
-
-		//
-		// Update interface.
-		//
-		if (unit->Player == ThisPlayer && unit->Selected) {
-			SelectedUnitChanged();
-		}
-	}
-	ClearSavedAction(unit);
-}
-
 /**
 **  Cast a spell at position or unit.
 **
@@ -1091,7 +860,7 @@ void CommandSpellCast(CUnit *unit, int x, int y, CUnit *dest,
 			// Unit::Refs is used as timeout counter.
 			//
 			if (dest->Destroyed) {
-				// FIXME: where check if spell needs an unit as destination?
+				// FIXME: where check if spell needs a unit as destination?
 				// FIXME: dest->Type is now set to 0. maybe we shouldn't bother.
 				order->X = dest->X /*+ dest->Type->TileWidth / 2*/  - order->Range;
 				order->Y = dest->Y /*+ dest->Type->TileHeight / 2*/ - order->Range;
@@ -1171,6 +940,7 @@ void CommandSharedVision(int player, bool state, int opponent)
 	int x;
 	int y;
 	int i;
+	CMapField *mf;
 
 	//
 	// Do a real hardcore seen recount. First we unmark EVERYTHING.
@@ -1198,15 +968,15 @@ void CommandSharedVision(int player, bool state, int opponent)
 		//
 		for (x = 0; x < Map.Info.MapWidth; ++x) {
 			for (y = 0; y < Map.Info.MapHeight; ++y) {
-				i = x + y * Map.Info.MapWidth;
-				if (Map.Fields[i].Visible[player] && !Map.Fields[i].Visible[opponent]) {
-					Map.Fields[i].Visible[opponent] = 1;
+				mf = Map.Field(x, y);
+				if (mf->Visible[player] && !mf->Visible[opponent]) {
+					mf->Visible[opponent] = 1;
 					if (opponent == ThisPlayer->Index) {
 						Map.MarkSeenTile(x, y);
 					}
 				}
-				if (Map.Fields[i].Visible[opponent] && !Map.Fields[i].Visible[player]) {
-					Map.Fields[i].Visible[player] = 1;
+				if (mf->Visible[opponent] && !mf->Visible[player]) {
+					mf->Visible[player] = 1;
 					if (player == ThisPlayer->Index) {
 						Map.MarkSeenTile(x, y);
 					}
