@@ -9,7 +9,7 @@
 //
 /**@name ai.cpp - The computer player AI main file. */
 //
-//      (c) Copyright 2000-2006 by Lutz Sammer, Ludovic Pollet, and
+//      (c) Copyright 2000-2007 by Lutz Sammer, Ludovic Pollet, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: ai.cpp 8550 2007-02-10 12:33:10Z feb $
+//      $Id: ai.cpp 8854 2007-06-03 22:04:42Z jim4 $
 
 
 //@{
@@ -97,11 +97,11 @@
 **
 ** ::AiHelpMe()
 **
-** Called if an unit owned by the AI is attacked.
+** Called if a unit owned by the AI is attacked.
 **
 ** ::AiUnitKilled()
 **
-** Called if an unit owned by the AI is killed.
+** Called if a unit owned by the AI is killed.
 **
 ** ::AiNeedMoreSupply()
 **
@@ -110,7 +110,7 @@
 **
 ** ::AiWorkComplete()
 **
-** Called if an unit has completed its work.
+** Called if a unit has completed its work.
 **
 ** ::AiCanNotBuild()
 **
@@ -123,14 +123,6 @@
 ** ::AiTrainingComplete()
 **
 ** Called if AI unit has completed training a new unit.
-**
-** ::AiUpgradeToComplete()
-**
-** Called if AI unit has completed upgrade to new unit-type.
-**
-** ::AiResearchComplete()
-**
-** Called if AI unit has completed research of an upgrade or spell.
 */
 
 /*----------------------------------------------------------------------------
@@ -174,12 +166,10 @@ PlayerAi *AiPlayer;             /// Current AI player
 */
 static void AiExecuteScript(void)
 {
-	PlayerAi *pai = AiPlayer;
-
-	if (!pai->Script.empty()) {
+	if (!AiPlayer->Script.empty()) {
 		lua_pushstring(Lua, "_ai_scripts_");
 		lua_gettable(Lua, LUA_GLOBALSINDEX);
-		lua_pushstring(Lua, pai->Script.c_str());
+		lua_pushstring(Lua, AiPlayer->Script.c_str());
 		lua_rawget(Lua, -2);
 		LuaCall(0, 1);
 		lua_pop(Lua, 1);
@@ -195,14 +185,9 @@ static void AiCheckUnits(void)
 	int attacking[UnitTypeMax];
 	const int *unit_types_count;
 	int i;
-	int j;
-	int n;
-	int t;
-	int x;
-	int e;
 
-	memset(counter, 0, sizeof (counter));
-	memset(attacking,0,sizeof(attacking));
+	memset(counter, 0, sizeof(counter));
+	memset(attacking, 0, sizeof(attacking));
 
 	//
 	//  Count the already made build requests.
@@ -212,51 +197,40 @@ static void AiCheckUnits(void)
 		counter[queue->Type->Slot] += queue->Want;
 	}
 
-	//
-	//  Remove non active units.
-	//
-	n = AiPlayer->Player->TotalNumUnits;
-	for (i = 0; i < n; ++i) {
-		if (!AiPlayer->Player->Units[i]->Active) {
-			counter[AiPlayer->Player->Units[i]->Type->Slot]--;
-		}
-	}
 	unit_types_count = AiPlayer->Player->UnitTypesCount;
 
 	//
 	//  Look if some unit-types are missing.
 	//
-	n = AiPlayer->UnitTypeRequests.size();
-	for (i = 0; i < n; ++i) {
-		t = AiPlayer->UnitTypeRequests[i].Type->Slot;
-		x = AiPlayer->UnitTypeRequests[i].Count;
+	for (i = 0; i < (int)AiPlayer->UnitTypeRequests.size(); ++i) {
+		int slot = AiPlayer->UnitTypeRequests[i].Type->Slot;
+		int count = AiPlayer->UnitTypeRequests[i].Count;
+		int e;
 
 		//
 		// Add equivalent units
 		//
-		e = unit_types_count[t];
-		if (t < (int)AiHelpers.Equiv.size()) {
-			for (j = 0; j < (int)AiHelpers.Equiv[t].size(); ++j) {
-				e += unit_types_count[AiHelpers.Equiv[t][j]->Slot];
+		e = unit_types_count[slot];
+		if (slot < (int)AiHelpers.Equiv.size()) {
+			for (int j = 0; j < (int)AiHelpers.Equiv[slot].size(); ++j) {
+				e += unit_types_count[AiHelpers.Equiv[slot][j]->Slot];
 			}
 		}
 
-		if (x > e + counter[t]) {  // Request it.
+		if (count > e + counter[slot]) {  // Request it.
 			AiAddUnitTypeRequest(AiPlayer->UnitTypeRequests[i].Type,
-				x - e - counter[t]);
-			counter[t] += x - e - counter[t];
+				count - e - counter[slot]);
+			counter[slot] += count - e - counter[slot];
 		}
-		counter[t] -= x;
+		counter[slot] -= count;
 	}
 
 	//
 	// Look through the forces what is missing.
 	//
 	for (i = AI_MAX_FORCES; i < AI_MAX_ATTACKING_FORCES; ++i) {
-
-		for (j = 0; j < (int)AiPlayer->Force[i].Units.size(); ++j) {
-			const CUnit *unit = AiPlayer->Force[i].Units[j];
-			attacking[unit->Type->Slot]++;
+		for (int j = 0; j < (int)AiPlayer->Force[i].Units.size(); ++j) {
+			attacking[AiPlayer->Force[i].Units[j]->Type->Slot]++;
 		}
 	}
 
@@ -269,53 +243,17 @@ static void AiCheckUnits(void)
 			continue;
 		}
 
-		for (j = 0; j < (int)AiPlayer->Force[i].UnitTypes.size(); ++j) {
+		for (int j = 0; j < (int)AiPlayer->Force[i].UnitTypes.size(); ++j) {
 			const AiUnitType *aiut = &AiPlayer->Force[i].UnitTypes[j];
-			t = aiut->Type->Slot;
-			x = aiut->Want;
-			if (x > unit_types_count[t] + counter[t] - attacking[t]) {    // Request it.
+			int slot = aiut->Type->Slot;
+			int want = aiut->Want;
+			if (want > unit_types_count[slot] + counter[slot] - attacking[slot]) {    // Request it.
 				AiAddUnitTypeRequest(aiut->Type,
-					x - (unit_types_count[t] + counter[t] - attacking[t]));
-				counter[t] += x - (unit_types_count[t] + counter[t] - attacking[t]);
+					want - (unit_types_count[slot] + counter[slot] - attacking[slot]));
+				counter[slot] += want - (unit_types_count[slot] + counter[slot] - attacking[slot]);
 				AiPlayer->Force[i].Completed = false;
 			}
-			counter[t] -= x;
-		}
-	}
-
-	//
-	//  Look if some upgrade-to are missing.
-	//
-	n = AiPlayer->UpgradeToRequests.size();
-	for (i = 0; i < n; ++i) {
-		t = AiPlayer->UpgradeToRequests[i]->Slot;
-		x = 1;
-
-		//
-		//  Add equivalent units
-		//
-		e = unit_types_count[t];
-		if (t < (int)AiHelpers.Equiv.size()) {
-			for (j = 0; j < (int)AiHelpers.Equiv[t].size(); ++j) {
-				e += unit_types_count[AiHelpers.Equiv[t][j]->Slot];
-			}
-		}
-
-		if (x > e + counter[t]) {  // Request it.
-			AiAddUpgradeToRequest(AiPlayer->UpgradeToRequests[i]);
-			counter[t] += x - e - counter[t];
-		}
-		counter[t] -= x;
-	}
-
-	//
-	//  Look if some researches are missing.
-	//
-	n = (int)AiPlayer->ResearchRequests.size();
-	for (i = 0; i < n; ++i) {
-		if (UpgradeIdAllowed(AiPlayer->Player,
-				AiPlayer->ResearchRequests[i]->ID) == 'A') {
-			AiAddResearchRequest(AiPlayer->ResearchRequests[i]);
+			counter[slot] -= want;
 		}
 	}
 }
@@ -382,34 +320,16 @@ static void SaveAiPlayer(CFile *file, int plynr, PlayerAi *ai)
 		file->printf("},\n");
 	}
 
-	file->printf("  \"reserve\", {");
-	for (i = 0; i < MaxCosts; ++i) {
-		file->printf("\"%s\", %d, ", DefaultResourceNames[i], ai->Reserve[i]);
-	}
-	file->printf("},\n");
-
-	file->printf("  \"used\", {");
-	for (i = 0; i < MaxCosts; ++i) {
-		file->printf("\"%s\", %d, ", DefaultResourceNames[i], ai->Used[i]);
-	}
-	file->printf("},\n");
-
 	file->printf("  \"needed\", {");
 	for (i = 0; i < MaxCosts; ++i) {
-		file->printf("\"%s\", %d, ", DefaultResourceNames[i], ai->Needed[i]);
-	}
-	file->printf("},\n");
-
-	file->printf("  \"collect\", {");
-	for (i = 0; i < MaxCosts; ++i) {
-		file->printf("\"%s\", %d, ", DefaultResourceNames[i], ai->Collect[i]);
+		file->printf("\"%s\", %d, ", DefaultResourceNames[i].c_str(), ai->Needed[i]);
 	}
 	file->printf("},\n");
 
 	file->printf("  \"need-mask\", {");
 	for (i = 0; i < MaxCosts; ++i) {
 		if (ai->NeededMask & (1 << i)) {
-			file->printf("\"%s\", ", DefaultResourceNames[i]);
+			file->printf("\"%s\", ", DefaultResourceNames[i].c_str());
 		}
 	}
 	file->printf("},\n");
@@ -447,18 +367,6 @@ static void SaveAiPlayer(CFile *file, int plynr, PlayerAi *ai)
 	}
 	file->printf("},\n");
 
-	file->printf("  \"upgrade\", {");
-	for (i = 0; i < (int)ai->UpgradeToRequests.size(); ++i) {
-		file->printf("\"%s\", ", ai->UpgradeToRequests[i]->Ident.c_str());
-	}
-	file->printf("},\n");
-
-	file->printf("  \"research\", {");
-	for (i = 0; i < (int)ai->ResearchRequests.size(); ++i) {
-		file->printf("\"%s\", ", ai->ResearchRequests[i]->Ident.c_str());
-	}
-	file->printf("},\n");
-
 	//
 	//  Building queue
 	//
@@ -502,7 +410,7 @@ static void SaveAiPlayers(CFile *file)
 void SaveAi(CFile *file)
 {
 	file->printf("\n--- -----------------------------------------\n");
-	file->printf("--- MODULE: AI $Id: ai.cpp 8550 2007-02-10 12:33:10Z feb $\n\n");
+	file->printf("--- MODULE: AI $Id: ai.cpp 8854 2007-06-03 22:04:42Z jim4 $\n\n");
 
 	SaveAiPlayers(file);
 
@@ -562,10 +470,6 @@ void AiInit(CPlayer *player)
 	pai->AiType = ait;
 	pai->Script = ait->Script;
 
-	pai->Collect[GoldCost] = 50;
-	pai->Collect[WoodCost] = 50;
-	pai->Collect[OilCost] = 0;
-
 	player->Ai = pai;
 }
 
@@ -614,8 +518,6 @@ void FreeAi()
 	//
 	AiHelpers.Train.clear();
 	AiHelpers.Build.clear();
-	AiHelpers.Upgrade.clear();
-	AiHelpers.Research.clear();
 	AiHelpers.Repair.clear();
 	AiHelpers.UnitLimit.clear();
 	AiHelpers.Equiv.clear();
@@ -801,7 +703,7 @@ void AiHelpMe(const CUnit *attacker, CUnit *defender)
 }
 
 /**
-**  Called if an unit is killed.
+**  Called if a unit is killed.
 **
 **  @param unit  Pointer to unit.
 */
@@ -1020,7 +922,7 @@ static void AiMoveUnitInTheWay(CUnit *unit)
 }
 
 /**
-**  Called if an unit can't move. Try to move unit in the way
+**  Called if a unit can't move. Try to move unit in the way
 **
 **  @param unit  Pointer to unit what builds the building.
 */
@@ -1071,7 +973,7 @@ void AiNeedMoreSupply(const CUnit *unit, const CUnitType *what)
 }
 
 /**
-**  Called if training of an unit is completed.
+**  Called if training of a unit is completed.
 **
 **  @param unit  Pointer to unit making.
 **  @param what  Pointer to new ready trained unit.
@@ -1091,38 +993,6 @@ void AiTrainingComplete(CUnit *unit, CUnit *what)
 	AiAssignToForce(what);
 }
 
-/**
-**  Called if upgrading of an unit is completed.
-**
-**  @param unit Pointer to unit working.
-**  @param what Pointer to the new unit-type.
-*/
-void AiUpgradeToComplete(CUnit *unit, const CUnitType *what)
-{
-	DebugPrint("%d: %d(%s) upgrade-to %s at %d,%d completed\n" _C_
-		unit->Player->Index _C_ UnitNumber(unit) _C_ unit->Type->Ident.c_str() _C_
-		what->Ident.c_str() _C_ unit->X _C_ unit->Y);
-
-	Assert(unit->Player->Type != PlayerPerson);
-}
-
-/**
-**  Called if reseaching of an unit is completed.
-**
-**  @param unit  Pointer to unit working.
-**  @param what  Pointer to the new upgrade.
-*/
-void AiResearchComplete(CUnit *unit, const CUpgrade *what)
-{
-	DebugPrint("%d: %d(%s) research %s at %d,%d completed\n" _C_
-		unit->Player->Index _C_ UnitNumber(unit) _C_ unit->Type->Ident.c_str() _C_
-		what->Ident.c_str() _C_ unit->X _C_ unit->Y);
-
-	Assert(unit->Player->Type != PlayerPerson);
-
-	// FIXME: upgrading knights -> paladins, must rebuild lists!
-}
-
 /**
 **  This is called for each player, each game cycle.
 **
