@@ -9,7 +9,7 @@
 //
 /**@name ai_resource.cpp - AI resource manager. */
 //
-//      (c) Copyright 2000-2005 by Lutz Sammer and Antonis Chaniotis.
+//      (c) Copyright 2000-2007 by Lutz Sammer and Antonis Chaniotis.
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: ai_resource.cpp 8550 2007-02-10 12:33:10Z feb $
+//      $Id: ai_resource.cpp 8933 2007-06-24 19:07:27Z jim4 $
 
 //@{
 
@@ -57,8 +57,6 @@
 --  Functions
 ----------------------------------------------------------------------------*/
 
-static int AiMakeUnit(CUnitType *type);
-
 /**
 **  Check if the costs are available for the AI.
 **
@@ -70,45 +68,12 @@ static int AiMakeUnit(CUnitType *type);
 */
 static int AiCheckCosts(const int *costs)
 {
-	int i;
-	int j;
-	int k;
-	int err;
-	const int *resources;
-	const int *reserve;
-	int *used;
-	int nunits;
-	CUnit **units;
-	const int *building_costs;
+	int err = 0;
 
-
-	// FIXME: the used costs shouldn't be calculated here
-	used = AiPlayer->Used;
-	for (j = 1; j < MaxCosts; ++j) {
-		used[j] = 0;
-	}
-
-	nunits = AiPlayer->Player->TotalNumUnits;
-	units = AiPlayer->Player->Units;
-	for (i = 0; i < nunits; ++i) {
-		for (k = 0; k < units[i]->OrderCount; ++k) {
-			if (units[i]->Orders[k]->Action == UnitActionBuild) {
-				building_costs =
-					units[i]->Orders[k]->Type->Stats[AiPlayer->Player->Index].Costs;
-				for (j = 1; j < MaxCosts; ++j) {
-					used[j] += building_costs[j];
-				}
-			}
-		}
-	}
-
-
-	err = 0;
-	resources = AiPlayer->Player->Resources;
-	reserve = AiPlayer->Reserve;
-	for (i = 1; i < MaxCosts; ++i) {
-		if (resources[i] - used[i] < costs[i] - reserve[i]) {
-			err |= 1 << i;
+	for (int i = 0; i < MaxCosts; ++i) {
+		if (costs[i] && AiPlayer->Player->ProductionRate[i] == 0 &&
+				AiPlayer->Player->StoredResources[i] == 0) {
+			err |= (1 << i);
 		}
 	}
 
@@ -116,56 +81,7 @@ static int AiCheckCosts(const int *costs)
 }
 
 /**
-**  Check if the AI player needs food.
-**
-**  It counts buildings in progress and units in training queues.
-**
-**  @param pai   AI player.
-**  @param type  Unit-type that should be build.
-**
-**  @return      True if enought, false otherwise.
-**
-**  @todo  The number of food currently trained can be stored global
-**         for faster use.
-*/
-static int AiCheckSupply(const PlayerAi *pai, const CUnitType *type)
-{
-	int remaining;
-	const AiBuildQueue *queue;
-	int i;
-
-	//
-	// Count food supplies under construction.
-	//
-	remaining = 0;
-	for (i = 0; i < (int)pai->UnitTypeBuilt.size(); ++i) {
-		queue = &pai->UnitTypeBuilt[i];
-		if (queue->Type->Supply) {
-			remaining += queue->Made * queue->Type->Supply;
-		}
-	}
-
-	//
-	// We are already out of food.
-	//
-	remaining += pai->Player->Supply - pai->Player->Demand - type->Demand;
-	if (remaining < 0) {
-		return 0;
-	}
-	//
-	// Count what we train.
-	//
-	for (i = 0; i < (int)pai->UnitTypeBuilt.size(); ++i) {
-		queue = &pai->UnitTypeBuilt[i];
-		if ((remaining -= queue->Made * queue->Type->Demand) < 0) {
-			return 0;
-		}
-	}
-	return 1;
-}
-
-/**
-**  Check if the costs for an unit-type are available for the AI.
+**  Check if the costs for a unit-type are available for the AI.
 **
 **  Take reserve and already used resources into account.
 **
@@ -175,39 +91,32 @@ static int AiCheckSupply(const PlayerAi *pai, const CUnitType *type)
 */
 static int AiCheckUnitTypeCosts(const CUnitType *type)
 {
-	return AiCheckCosts(type->Stats[AiPlayer->Player->Index].Costs);
+	return AiCheckCosts(type->ProductionCosts);
 }
 
 /**
 **  Enemy units in distance.
 **
-**  @param unit  Find in distance for this unit.
-**  @param range Distance range to look.
+**  @param player  Find enemies of this player
+**  @param type    Optional unit type to check if enemy can target this
+**  @param x       X location
+**  @param y       Y location
+**  @param range   Distance range to look.
 **
-**  @return      Number of enemy units.
+**  @return       Number of enemy units.
 */
-int EnemyUnitsInDistance(const CUnit *unit, unsigned range)
+int AiEnemyUnitsInDistance(const CPlayer *player, const CUnitType *type, int x, int y, unsigned range)
 {
 	const CUnit *dest;
-	const CUnitType *type;
 	CUnit *table[UnitMax];
-	unsigned x;
-	unsigned y;
 	unsigned n;
 	unsigned i;
 	int e;
-	const CPlayer *player;
 
 	//
 	// Select all units in range.
 	//
-	x = unit->X;
-	y = unit->Y;
-	n = UnitCacheSelect(x - range, y - range, x + range + unit->Type->TileWidth,
-		y + range + unit->Type->TileHeight, table);
-
-	player = unit->Player;
-	type = unit->Type;
+	n = UnitCacheSelect(x - range, y - range, x + range, y + range, table);
 
 	//
 	// Find the enemy units which can attack
@@ -217,8 +126,7 @@ int EnemyUnitsInDistance(const CUnit *unit, unsigned range)
 		//
 		// Those can't attack anyway.
 		//
-		if (dest->Removed || dest->Variable[INVISIBLE_INDEX].Value ||
-			dest->Orders[0]->Action == UnitActionDie) {
+		if (dest->Removed || dest->Orders[0]->Action == UnitActionDie) {
 			continue;
 		}
 
@@ -228,7 +136,7 @@ int EnemyUnitsInDistance(const CUnit *unit, unsigned range)
 		//
 		// Unit can attack back?
 		//
-		if (CanTarget(dest->Type, type)) {
+		if (!type || CanTarget(dest->Type, type)) {
 			++e;
 		}
 	}
@@ -236,6 +144,20 @@ int EnemyUnitsInDistance(const CUnit *unit, unsigned range)
 	return e;
 }
 
+/**
+**  Enemy units in distance.
+**
+**  @param unit   Find in distance for this unit.
+**  @param range  Distance range to look.
+**
+**  @return       Number of enemy units.
+*/
+int AiEnemyUnitsInDistance(const CUnit *unit, unsigned range)
+{
+	range += std::max<int>(unit->Type->TileWidth, unit->Type->TileHeight);
+	return AiEnemyUnitsInDistance(unit->Player, unit->Type, unit->X, unit->Y, range);
+}
+
 /**
 **  Check if we can build the building.
 **
@@ -256,9 +178,6 @@ static int AiBuildBuilding(const CUnitType *type, CUnitType *building)
 	int x;
 	int y;
 
-#ifdef DEBUG
-	unit = NoUnitP;
-#endif
 	//
 	// Remove all workers on the way building something
 	//
@@ -266,8 +185,8 @@ static int AiBuildBuilding(const CUnitType *type, CUnitType *building)
 	for (num = i = 0; i < nunits; ++i) {
 		unit = table[i];
 		for (x = 0; x < unit->OrderCount; ++x) {
-			if (unit->Orders[x]->Action == UnitActionBuild
-				|| unit->Orders[x]->Action == UnitActionRepair) {
+			if (unit->Orders[x]->Action == UnitActionBuild ||
+					unit->Orders[x]->Action == UnitActionRepair) {
 				break;
 			}
 		}
@@ -276,87 +195,22 @@ static int AiBuildBuilding(const CUnitType *type, CUnitType *building)
 		}
 	}
 
-	for (i = 0; i < num; ++i) {
+	if (num == 0) {
+		// No workers available to build
+		return 0;
+	}
 
-		unit = table[i];
-
-		//
-		// Find place on that could be build.
-		//
-		if (!AiFindBuildingPlace(unit, building, &x, &y)) {
-			continue;
-		}
+	// Try one worker at random to save cpu
+	unit = table[SyncRand() % num];
 
+	// Find a place to build.
+	if (AiFindBuildingPlace(unit, building, &x, &y)) {
 		CommandBuildBuilding(unit, x, y, building, FlushCommands);
-
 		return 1;
 	}
-
 	return 0;
 }
 
-/**
-**  Build new units to reduce the food shortage.
-*/
-static void AiRequestSupply(void)
-{
-	int i;
-	int n;
-	int c;
-	CUnitType *type;
-	AiBuildQueue *queue;
-	int counter[UnitTypeMax];
-	unsigned int needmask;
-
-	//
-	// Don't request supply if we're sleeping.  When the script starts it may
-	// request a better unit than the one we pick here.  If we only have enough
-	// resources for one unit we don't want to build the wrong one.
-	//
-	if (AiPlayer->SleepCycles != 0) {
-		return;
-	}
-
-	//
-	// Count the already made build requests.
-	//
-	memset(counter, 0, sizeof(counter));
-	for (i = 0; i < (int)AiPlayer->UnitTypeBuilt.size(); ++i) {
-		queue = &AiPlayer->UnitTypeBuilt[i];
-		counter[queue->Type->Slot] += queue->Want;
-	}
-
-	//
-	// Check if we can build this?
-	//
-	n = AiHelpers.UnitLimit[0].size();
-	needmask = 0;
-	for (i = 0; i < n; ++i) {
-		type = AiHelpers.UnitLimit[0][i];
-		if (counter[type->Slot]) { // Already ordered.
-			return;
-		}
-
-		//
-		// Check if resources available.
-		//
-		if ((c = AiCheckUnitTypeCosts(type))) {
-			needmask |= c;
-		} else {
-			if (AiMakeUnit(type)) {
-				AiBuildQueue newqueue;
-				newqueue.Type = type;
-				newqueue.Want = 1;
-				newqueue.Made = 1;
-				AiPlayer->UnitTypeBuilt.insert(
-					AiPlayer->UnitTypeBuilt.begin(), newqueue);
-				return ;
-			}
-		}
-		AiPlayer->NeededMask |= needmask;
-	}
-}
-
 /**
 **  Check if we can train the unit.
 **
@@ -375,10 +229,6 @@ static int AiTrainUnit(const CUnitType *type, CUnitType *what)
 	int i;
 	int num;
 
-#ifdef DEBUG
-	unit = NoUnitP;
-#endif
-
 	//
 	// Remove all units already doing something.
 	//
@@ -420,7 +270,7 @@ int AiCountUnitBuilders(CUnitType *type)
 		return 0;
 	}
 	//
-	// Check if we have a place for building or an unit to build.
+	// Check if we have a place for building or a unit to build.
 	//
 	if (type->Building) {
 		n = AiHelpers.Build.size();
@@ -451,7 +301,7 @@ int AiCountUnitBuilders(CUnitType *type)
 }
 
 /**
-**  Check if we can make an unit-type.
+**  Check if we can make a unit-type.
 **
 **  @param type  Unit-type that must be made.
 **
@@ -480,7 +330,7 @@ static int AiMakeUnit(CUnitType *type)
 		type = UnitTypes[usableTypes[currentType]];
 
 		//
-		// Check if we have a place for building or an unit to build.
+		// Check if we have a place for building or a unit to build.
 		//
 		if (type->Building) {
 			n = AiHelpers.Build.size();
@@ -520,192 +370,6 @@ static int AiMakeUnit(CUnitType *type)
 	return 0;
 }
 
-/**
-**  Check if we can research the upgrade.
-**
-**  @param type  Unit that can research the upgrade.
-**  @param what  What should be researched.
-**
-**  @return      True if made, false if can't be made.
-**
-**  @note        We must check if the dependencies are fulfilled.
-*/
-static int AiResearchUpgrade(const CUnitType *type, CUpgrade *what)
-{
-	CUnit *table[UnitMax];
-	CUnit *unit;
-	int nunits;
-	int i;
-	int num;
-
-#ifdef DEBUG
-	unit = NoUnitP;
-#endif
-	// Remove all units already doing something.
-	//
-	nunits = FindPlayerUnitsByType(AiPlayer->Player, type, table);
-	for (num = i = 0; i < nunits; ++i) {
-		unit = table[i];
-		if (unit->IsIdle()) {
-			table[num++] = unit;
-		}
-	}
-
-	for (i = 0; i < num; ++i) {
-		unit = table[i];
-
-		CommandResearch(unit, what, FlushCommands);
-
-		return 1;
-	}
-
-	return 0;
-}
-
-/**
-**  Check if the research can be done.
-**
-**  @param upgrade  Upgrade to research
-*/
-void AiAddResearchRequest(CUpgrade *upgrade)
-{
-	int i;
-	int n;
-	const int *unit_count;
-	std::vector<std::vector<CUnitType *> > *tablep;
-	std::vector<CUnitType *> *table;
-
-	//
-	// Check if resources are available.
-	//
-	if ((i = AiCheckCosts(upgrade->Costs))) {
-		AiPlayer->NeededMask |= i;
-		return;
-	}
-	//
-	// Check if we have a place for the upgrade to research
-	//
-	n = AiHelpers.Research.size();
-	tablep = &AiHelpers.Research;
-
-	if (upgrade->ID > n) { // Oops not known.
-		DebugPrint("Nothing known about `%s'\n" _C_ upgrade->Ident.c_str());
-		return;
-	}
-	table = &(*tablep)[upgrade->ID];
-	if (!table->size()) { // Oops not known.
-		DebugPrint("Nothing known about `%s'\n" _C_ upgrade->Ident.c_str());
-		return;
-	}
-
-	unit_count = AiPlayer->Player->UnitTypesCount;
-	for (i = 0; i < (int)table->size(); ++i) {
-		//
-		// The type is available
-		//
-		if (unit_count[(*table)[i]->Slot]) {
-			if (AiResearchUpgrade((*table)[i], upgrade)) {
-				return;
-			}
-		}
-	}
-
-	return;
-}
-
-/**
-**  Check if we can upgrade to unit-type.
-**
-**  @param type  Unit that can upgrade to unit-type
-**  @param what  To what should be upgraded.
-**
-**  @return      True if made, false if can't be made.
-**
-**  @note        We must check if the dependencies are fulfilled.
-*/
-static int AiUpgradeTo(const CUnitType *type, CUnitType *what)
-{
-	CUnit *table[UnitMax];
-	CUnit *unit;
-	int nunits;
-	int i;
-	int num;
-
-#ifdef DEBUG
-	unit = NoUnitP;
-#endif
-	// Remove all units already doing something.
-	//
-	nunits = FindPlayerUnitsByType(AiPlayer->Player, type, table);
-	for (num = i = 0; i < nunits; ++i) {
-		unit = table[i];
-		if (unit->IsIdle()) {
-			table[num++] = unit;
-		}
-	}
-
-	for (i = 0; i < num; ++i) {
-		unit = table[i];
-
-		CommandUpgradeTo(unit, what, FlushCommands);
-
-		return 1;
-	}
-
-	return 0;
-}
-
-/**
-**  Check if the upgrade-to can be done.
-**
-**  @param type  FIXME: docu
-*/
-void AiAddUpgradeToRequest(CUnitType *type)
-{
-	int i;
-	int n;
-	const int *unit_count;
-	std::vector<std::vector<CUnitType *> > *tablep;
-	std::vector<CUnitType *> *table;
-
-	//
-	// Check if resources are available.
-	//
-	if ((i = AiCheckUnitTypeCosts(type))) {
-		AiPlayer->NeededMask |= i;
-		return;
-	}
-	//
-	// Check if we have a place for the upgrade to.
-	//
-	n = AiHelpers.Upgrade.size();
-	tablep = &AiHelpers.Upgrade;
-
-	if (type->Slot > n) { // Oops not known.
-		DebugPrint("Nothing known about `%s'\n" _C_ type->Ident.c_str());
-		return;
-	}
-	table = &(*tablep)[type->Slot];
-	if (!table->size()) { // Oops not known.
-		DebugPrint("Nothing known about `%s'\n" _C_ type->Ident.c_str());
-		return;
-	}
-
-	unit_count = AiPlayer->Player->UnitTypesCount;
-	for (i = 0; i < (int)table->size(); ++i) {
-		//
-		// The type is available
-		//
-		if (unit_count[(*table)[i]->Slot]) {
-			if (AiUpgradeTo((*table)[i], type)) {
-				return;
-			}
-		}
-	}
-
-	return;
-}
-
 /**
 **  Check what must be built / trained.
 */
@@ -715,54 +379,45 @@ static void AiCheckingWork(void)
 	CUnitType *type;
 	AiBuildQueue *queue;
 
-	// Suppy has the highest priority
-	if (AiPlayer->NeedSupply) {
-		if (!(!AiPlayer->UnitTypeBuilt.empty() &&
-				AiPlayer->UnitTypeBuilt[0].Type->Supply)) {
-			AiPlayer->NeedSupply = false;
-			AiRequestSupply();
-		}
-	}
 	//
 	// Look to the build requests, what can be done.
 	//
 	int sz = AiPlayer->UnitTypeBuilt.size();
 	for (int i = 0; i < sz; ++i) {
 		queue = &AiPlayer->UnitTypeBuilt[AiPlayer->UnitTypeBuilt.size() - sz + i];
-		if (queue->Want > queue->Made) {
-			type = queue->Type;
+		type = queue->Type;
 
-			//
-			// FIXME: must check if requirements are fulfilled.
-			// Buildings can be destroyed.
+		//
+		// FIXME: must check if requirements are fulfilled.
+		// Buildings can be destroyed.
 
+		//
+		// Check limits, AI should be broken if reached.
+		//
+		if (queue->Want > queue->Made && AiPlayer->Player->CheckLimits(type) < 0) {
+			continue;
+		}
+		//
+		// Check if resources available.
+		//
+		if ((c = AiCheckUnitTypeCosts(type))) {
+			AiPlayer->NeededMask |= c;
 			//
-			// Check if we have enough food.
-			//
-			if (type->Demand && !AiCheckSupply(AiPlayer, type)) {
-				AiPlayer->NeedSupply = true;
-				AiRequestSupply();
-			}
-			//
-			// Check limits, AI should be broken if reached.
-			//
-			if (AiPlayer->Player->CheckLimits(type) < 0) {
-				continue;
-			}
-			//
-			// Check if resources available.
-			//
-			if ((c = AiCheckUnitTypeCosts(type))) {
-				AiPlayer->NeededMask |= c;
-				//
-				// NOTE: we can continue and build things with lesser
-				//  resource or other resource need!
-				continue;
-			} else {
-				if (AiMakeUnit(type)) {
-					// AiRequestSupply can change UnitTypeBuilt so recalculate queue
-					queue = &AiPlayer->UnitTypeBuilt[AiPlayer->UnitTypeBuilt.size() - sz + i];
-					++queue->Made;
+			// NOTE: we can continue and build things with lesser
+			//  resource or other resource need!
+			continue;
+		} else if (queue->Want > queue->Made && queue->Wait <= GameCycle) {
+			if (AiMakeUnit(type)) {
+				// AiRequestSupply can change UnitTypeBuilt so recalculate queue
+				queue = &AiPlayer->UnitTypeBuilt[AiPlayer->UnitTypeBuilt.size() - sz + i];
+				++queue->Made;
+				queue->Wait = 0;
+			} else if (queue->Type->Building) {
+				// Finding a building place is costly, don't try again for a while
+				if (queue->Wait == 0) {
+					queue->Wait = GameCycle + 150;
+				} else {
+					queue->Wait = GameCycle + 450;
 				}
 			}
 		}
@@ -774,10 +429,10 @@ static void AiCheckingWork(void)
 ----------------------------------------------------------------------------*/
 
 /**
-**  Assign worker to gather a certain resource.
+**  Assign worker to gather a resource.
 **
-**  @param unit      pointer to the unit.
-**  @param resource  resource identification.
+**  @param unit      Unit to be assigned.
+**  @param resource  Resource to find, -1 for any
 **
 **  @return          1 if the worker was assigned, 0 otherwise.
 */
@@ -786,22 +441,40 @@ static int AiAssignHarvester(CUnit *unit, int resource)
 	std::vector<CUnitType *>::iterator i;
 	int exploremask;
 	CUnit *dest;
+	int res = resource;
 
 	// It can't.
 	if (unit->Removed) {
 		return 0;
 	}
 
+	if (res == -1) {
+		// No resource specified, see which resource we need most
+		for (int i = 0; i < MaxCosts; ++i) {
+			if (unit->Player->ProductionRate[i] == 0) {
+				res = i;
+				if (unit->Player->StoredResources[i] == 0) {
+					break;
+				}
+			}
+		}
+	}
+
 	//
 	// Find a resource to harvest from.
 	//
-	if ((dest = UnitFindResource(unit, unit->X, unit->Y, 1000, resource))) {
+	dest = UnitFindResource(unit, unit->X, unit->Y, 1000, res);
+	if (!dest && res != -1) {
+		dest = UnitFindResource(unit, unit->X, unit->Y, 1000, -1);
+	}
+	if (dest) {
 		CommandResource(unit, dest, FlushCommands);
 		return 1;
 	}
+
 	exploremask = 0;
 	for (i = UnitTypes.begin(); i != UnitTypes.end(); i++) {
-		if (*i && (*i)->GivesResource == resource) {
+		if (*i && (*i)->CanHarvestFrom) {
 			switch ((*i)->UnitType) {
 			case UnitTypeLand:
 				exploremask |= MapFieldLandUnit;
@@ -826,236 +499,70 @@ static int AiAssignHarvester(CUnit *unit, int resource)
 
 /**
 **  Assign workers to collect resources.
-**
-**  If we have a shortage of a resource, let many workers collecting this.
-**  If no shortage, split workers to all resources.
 */
 static void AiCollectResources(void)
 {
-	CUnit *units_with_resource[UnitMax][MaxCosts]; // Worker with resource
-	CUnit *units_assigned[UnitMax][MaxCosts]; // Worker assigned to resource
-	CUnit *units_unassigned[UnitMax][MaxCosts]; // Unassigned workers
-	int num_units_with_resource[MaxCosts];
-	int num_units_assigned[MaxCosts];
-	int num_units_unassigned[MaxCosts];
-	int total; // Total of workers
-	int c;
-	int src_c;
 	int i;
-	int j;
-	int k;
-	int n;
-	CUnit **units;
-	CUnit *unit;
-	int percent[MaxCosts];
-	int percent_total;
+	int needed = -1;
+	std::vector<CUnit *> harvesters;
 
-	int priority_resource[MaxCosts];
-	int priority_needed[MaxCosts];
-	int wanted[MaxCosts];
-	int total_harvester;
-
-	//
-	// Collect statistics about the current assignment
-	//
-	percent_total = 100;
-	for (c = 0; c < MaxCosts; ++c) {
-		num_units_with_resource[c] = 0;
-		num_units_assigned[c] = 0;
-		num_units_unassigned[c] = 0;
-		percent[c] = AiPlayer->Collect[c];
-		if ((AiPlayer->NeededMask & (1 << c))) { // Double percent if needed
-			percent_total += percent[c];
-			percent[c] <<= 1;
+	// Check if we need a resource
+	if (AiPlayer->NeededMask) {
+		int n = AiPlayer->NeededMask;
+		while (n != 0) {
+			n >>= 1;
+			++needed;
 		}
 	}
 
-	total_harvester = 0;
+	// Build a list of all harvesters
+	for (i = 0; i < AiPlayer->Player->TotalNumUnits; ++i) {
+		CUnit *unit = AiPlayer->Player->Units[i];
 
-	n = AiPlayer->Player->TotalNumUnits;
-	units = AiPlayer->Player->Units;
-	for (i = 0; i < n; ++i) {
-		unit = units[i];
+		// Ignore non-harvesters
 		if (!unit->Type->Harvester) {
 			continue;
 		}
 
-		c = unit->CurrentResource;
-
-		//
-		// See if it's assigned already
-		//
-		if (unit->Orders[0]->Action == UnitActionResource && unit->OrderCount == 1 && c) {
-			units_assigned[num_units_assigned[c]++][c] = unit;
-			total_harvester++;
-			continue;
-		}
-
-		//
-		// Ignore busy units. ( building, fighting, ... )
-		//
-		if (!unit->IsIdle()) {
-			continue;
-		}
-
-		//
-		// Send workers with resources back home.
-		//
-		if (unit->ResourcesHeld && c) {
-			units_with_resource[num_units_with_resource[c]++][c] = unit;
-			CommandReturnGoods(unit, 0, FlushCommands);
-			total_harvester++;
-			continue;
-		}
-
-		//
-		// Look what the unit can do
-		//
-		for (c = 0; c < MaxCosts; ++c) {
-			if (unit->Type->ResInfo[c]) {
-				units_unassigned[num_units_unassigned[c]++][c] = unit;
-			}
-		}
-		++total_harvester;
+		harvesters.push_back(unit);
 	}
 
-	total = 0;
-	for (c = 0; c < MaxCosts; ++c) {
-		total += num_units_assigned[c] + num_units_with_resource[c];
-	}
-
-	//
-	// Turn percent values into harvester numbers.
-	//
-
-	// Wanted needs to be representative.
-	if (total_harvester < 5) {
-		total_harvester = 5;
-	}
-
-	for (c = 0; c < MaxCosts; ++c ) {
-		if (percent[c]) {
-			wanted[c] = 1 + (percent[c] * total_harvester) / percent_total;
-		} else {
-			wanted[c] = 0;
-		}
-	}
-
-	//
-	// Initialise priority & mapping
-	//
-	for (c = 0; c < MaxCosts; ++c) {
-		priority_resource[c] = c;
-		priority_needed[c] = wanted[c] - num_units_assigned[c] - num_units_with_resource[c];
-	}
-
-	do {
-		//
-		// sort resources by priority
-		//
-		for (i = 0; i < MaxCosts; ++i) {
-			for (j = i + 1; j < MaxCosts; ++j) {
-				if (priority_needed[j] > priority_needed[i]) {
-					c = priority_needed[j];
-					priority_needed[j] = priority_needed[i];
-					priority_needed[i] = c;
-					c = priority_resource[j];
-					priority_resource[j] = priority_resource[i];
-					priority_resource[i] = c;
-				}
-			}
-		}
-
-		//
-		// Try to complete each ressource in the priority order
-		//
-		unit = NoUnitP;
-		for (i = 0; i < MaxCosts; ++i) {
-			c = priority_resource[i];
-
-			//
-			// If there is a free worker for c, take it.
-			//
-			if (num_units_unassigned[c]) {
-				// Take the unit.
-				j = 0;
-				while (j < num_units_unassigned[c] && !AiAssignHarvester(units_unassigned[j][c], c)) {
-					// can't assign to c => remove from units_unassigned !
-					units_unassigned[j][c] = units_unassigned[--num_units_unassigned[c]][c];
-				}
-
-				// unit is assigned
-				if (j < num_units_unassigned[c]) {
-					unit = units_unassigned[j][c];
-					units_unassigned[j][c] = units_unassigned[--num_units_unassigned[c]][c];
-
-					// remove it from other ressources
-					for (j = 0; j < MaxCosts; ++j) {
-						if (j == c || !unit->Type->ResInfo[j]) {
-							continue;
-						}
-						for (k = 0; k < num_units_unassigned[j]; ++k) {
-							if (units_unassigned[k][j] == unit) {
-								units_unassigned[k][j] = units_unassigned[--num_units_unassigned[j]][j];
-								break;
-							}
-						}
-					}
-				}
-			}
-
-			//
-			// Else : Take from already assigned worker with lower priority.
-			//
-			if (!unit) {
-				// Take from lower priority only (i+1).
-				for (j = i + 1; j < MaxCosts; ++j) {
-					// Try to move worker from src_c to c
-					src_c = priority_resource[j];
-
-					// Don't complete with lower priority ones...
-					if (wanted[src_c] > wanted[c] ||
-							(wanted[src_c] == wanted[c] &&
-								num_units_assigned[src_c] <= num_units_assigned[c] + 1)) {
-						continue;
-					}
-
-					for (k = num_units_assigned[src_c] - 1; k >= 0 && !unit; --k) {
-						unit = units_assigned[k][src_c];
-
-						// unit can't harvest : next one
-						if (!unit->Type->ResInfo[c] || !AiAssignHarvester(unit, c)) {
-							unit = NoUnitP;
-							continue;
-						}
-
-						// Remove from src_c
-						units_assigned[k][src_c] = units_assigned[--num_units_assigned[src_c]][src_c];
-
-						// j need one more
-						priority_needed[j]++;
-					}
-				}
-			}
-
-			//
-			// We just moved an unit. Adjust priority & retry
-			//
-			if (unit) {
-				// i got a new unit.
-				priority_needed[i]--;
-
-				// Add to the assigned
-				units_assigned[num_units_assigned[c]++][c] = unit;
-
-				// Recompute priority now
+	// If we need a resource, pick one unit to harvest it
+	if (needed != -1 && harvesters.size() != 0) {
+		int best = -1;
+		for (i = 0; i < (int)harvesters.size(); ++i) {
+			// Idle units are always best
+			if (harvesters[i]->IsIdle()) {
+				best = i;
 				break;
 			}
+			// Unit harvesting the wrong resource
+			if (harvesters[i]->Orders[0]->Action == UnitActionResource &&
+					harvesters[i]->Data.Harvest.CurrentProduction[needed] == 0) {
+				best = i;
+			}
 		}
-	} while (unit);
 
-	// Unassigned units there can't be assigned ( ie : they can't move to ressource )
-	// IDEA : use transporter here.
+		if (best == -1) {
+			// No best unit found, pick one at random
+			best = SyncRand() % harvesters.size();
+		}
+
+		if (AiAssignHarvester(harvesters[best], needed)) {
+			harvesters.erase(harvesters.begin() + best);
+		}
+	}
+
+	// Assign one random idle harvester at a time
+	std::vector<CUnit *> idleHarvesters;
+	for (i = 0; i < (int)harvesters.size(); ++i) {
+		if (harvesters[i]->IsIdle()) {
+			idleHarvesters.push_back(harvesters[i]);
+		}
+	}
+	if (idleHarvesters.size() > 0) {
+		AiAssignHarvester(idleHarvesters[SyncRand() % idleHarvesters.size()], -1);
+	}
 }
 
 /*----------------------------------------------------------------------------
@@ -1208,53 +715,49 @@ static int AiRepairUnit(CUnit *unit)
 }
 
 /**
-**  Look through the units, if an unit must be repaired.
+**  Check if there's a unit that should be repaired.
 */
 static void AiCheckRepair(void)
 {
 	int i;
-	int j;
 	int k;
 	int n;
-	int repair_flag;
+	bool repair_flag;
 	CUnit *unit;
 
 	n = AiPlayer->Player->TotalNumUnits;
 	k = 0;
 	// Selector for next unit
-	for (i = n; (i > 0); --i) {
+	for (i = n - 1; i >= 0; --i) {
 		unit = AiPlayer->Player->Units[i];
-		if (unit) {
-			if (UnitNumber(unit) == AiPlayer->LastRepairBuilding) {
-				k = i + 1;
-			}
+		if (UnitNumber(unit) == AiPlayer->LastRepairBuilding) {
+			k = i + 1;
 		}
 	}
 
+
 	for (i = k; i < n; ++i) {
 		unit = AiPlayer->Player->Units[i];
-		repair_flag = 1;
+		repair_flag = true;
 		// Unit damaged?
-		// Don't repair attacked unit ( wait 5 sec before repairing )
+		// Don't repair attacked unit (wait 5 sec before repairing)
 		if (unit->Type->RepairHP &&
 				unit->Orders[0]->Action != UnitActionBuilt &&
-				unit->Orders[0]->Action != UnitActionUpgradeTo &&
 				unit->Variable[HP_INDEX].Value < unit->Variable[HP_INDEX].Max &&
 				unit->Attacked + 5 * CYCLES_PER_SECOND < GameCycle) {
 
-			//
 			// FIXME: Repair only units under control
-			//
-			if (EnemyUnitsInDistance(unit, unit->Stats->Variables[SIGHTRANGE_INDEX].Max)) {
+			if (AiEnemyUnitsInDistance(unit, unit->Stats->Variables[SIGHTRANGE_INDEX].Max)) {
 				continue;
 			}
 			//
-			// Must check, if there are enough resources
+			// Must check if there are enough resources
 			//
-			for (j = 1; j < MaxCosts; ++j) {
-				if (unit->Stats->Costs[j] &&
-						AiPlayer->Player->Resources[j] < 99) {
-					repair_flag = 0;
+			for (int j = 0; j < MaxCosts; ++j) {
+				if (unit->Type->ProductionCosts[j] && AiPlayer->Player->ProductionRate[j] == 0 &&
+						AiPlayer->Player->StoredResources[j] == 0) {
+					repair_flag = false;
+					break;
 				}
 			}
 
@@ -1267,6 +770,31 @@ static void AiCheckRepair(void)
 				return;
 			}
 		}
+
+		// Building under construction but no worker
+		if (unit->Orders[0]->Action == UnitActionBuilt) {
+			int j;
+			for (j = 0; j < AiPlayer->Player->TotalNumUnits; ++j) {
+				COrder *order = AiPlayer->Player->Units[j]->Orders[0];
+				if (order->Action == UnitActionRepair && order->Goal == unit) {
+					break;
+				}
+			}
+			if (j == AiPlayer->Player->TotalNumUnits) {
+				// Make sure we have enough resources first
+				for (j = 0; j < MaxCosts; ++j) {
+					// FIXME: the resources don't necessarily have to be in storage
+					if (AiPlayer->Player->StoredResources[j] < unit->Type->ProductionCosts[j]) {
+						break;
+					}
+				}
+				if (j == MaxCosts) {
+					AiRepairUnit(unit);
+					AiPlayer->LastRepairBuilding = UnitNumber(unit);
+					return;
+				}
+			}
+		}
 	}
 	AiPlayer->LastRepairBuilding = 0;
 }
@@ -1318,12 +846,7 @@ void AiResourceManager(void)
 	// Check if something needs to be build / trained.
 	//
 	AiCheckingWork();
-	//
-	// Look if we can build a farm in advance.
-	//
-	if (!AiPlayer->NeedSupply && AiPlayer->Player->Supply == AiPlayer->Player->Demand) {
-		AiRequestSupply();
-	}
+
 	//
 	// Collect resources.
 	//
