@@ -9,7 +9,7 @@
 //
 /**@name missile.h - The missile headerfile. */
 //
-//      (c) Copyright 1998-2005 by Lutz Sammer
+//      (c) Copyright 1998-2007 by Lutz Sammer
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@
 //      along with this program; if not, write to the Free Software
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
-//
-//      $Id: missile.h 8550 2007-02-10 12:33:10Z feb $
 
 #ifndef __MISSILE_H__
 #define __MISSILE_H__
@@ -198,7 +196,7 @@
 **  This structure contains all information about a missile in game.
 **  A missile could have different effects, based on its missile-type.
 **  Missiles could be saved and stored with CCL. See (missile).
-**  Currently only a tile, an unit or a missile could be placed on the map.
+**  Currently only a tile, a unit or a missile could be placed on the map.
 **
 **
 **  The missile structure members:
@@ -362,14 +360,6 @@ enum _missile_class_ {
 	MissileClassHit,
 	/// Missile flies from x,y to x1,y1 using a parabolic path
 	MissileClassParabolic,
-	/// Missile wait on x,y until a non-air unit comes by, the explodes.
-	MissileClassLandMine,
-	/// Missile appears at x,y, is whirlwind
-	MissileClassWhirlwind,
-	/// Missile surround x,y
-	MissileClassFlameShield,
-	/// Missile is death coil.
-	MissileClassDeathCoil
 };
 
 	/// Base structure of missile-types
@@ -517,22 +507,6 @@ class MissileParabolic : public Missile {
 public:
 	virtual void Action();
 };
-class MissileLandMine : public Missile {
-public:
-	virtual void Action();
-};
-class MissileWhirlwind : public Missile {
-public:
-	virtual void Action();
-};
-class MissileFlameShield : public Missile {
-public:
-	virtual void Action();
-};
-class MissileDeathCoil : public Missile {
-public:
-	virtual void Action();
-};
 
 class BurningBuildingFrame {
 public:
@@ -552,12 +526,12 @@ extern std::vector<BurningBuildingFrame *> BurningBuildingFrames;  /// Burning b
 --  Functions
 ----------------------------------------------------------------------------*/
 
-// In ccl_missile.c
+// In script_missile.cpp
 
 	/// register ccl features
 extern void MissileCclRegister(void);
 
-// In missile.c
+// In missile.cpp
 
 	/// load all missile sprites
 extern void LoadMissileSprites();
@@ -595,8 +569,9 @@ extern void CleanMissileTypes(void);
 extern void InitMissiles(void);
 	/// Clean missiles
 extern void CleanMissiles(void);
-
-
+#ifdef DEBUG
+extern void FreeBurningBuildingFrames();
+#endif
 
 //@}
 
