@@ -31,28 +31,21 @@
 //@{
 
 #include "SDL.h"
-
-#ifdef USE_OPENGL
 #include "SDL_opengl.h"
-class CFont;
-#endif
-
 #include "guichan/image.h"
 
+class CFont;
+
+extern bool UseOpenGL;
+
+
 class CGraphic : public gcn::Image {
 protected:
-	CGraphic() : Surface(NULL),
+	CGraphic() : Surface(NULL), SurfaceFlip(NULL),
 		Width(0), Height(0), NumFrames(1), GraphicWidth(0), GraphicHeight(0),
-		Refs(1), Resized(false)
+		Refs(1), Resized(false),
+		TextureWidth(0.f), TextureHeight(0.f), Textures(NULL), NumTextures(0)
 	{
-#ifndef USE_OPENGL
-		SurfaceFlip = NULL;
-#else
-		TextureWidth = 0.f;
-		TextureHeight = 0.f;
-		Textures = NULL;
-		NumTextures = 0;
-#endif
 	}
 	~CGraphic() {}
 
@@ -67,18 +60,14 @@ public:
 
 	// Draw frame
 	void DrawFrame(unsigned frame, int x, int y) const;
-#ifdef USE_OPENGL
 	void DoDrawFrameClip(GLuint *textures, unsigned frame, int x, int y) const;
-#endif
 	void DrawFrameClip(unsigned frame, int x, int y) const;
 	void DrawFrameTrans(unsigned frame, int x, int y, int alpha) const;
 	void DrawFrameClipTrans(unsigned frame, int x, int y, int alpha) const;
 
 	// Draw frame flipped horizontally
 	void DrawFrameX(unsigned frame, int x, int y) const;
-#ifdef USE_OPENGL
 	void DoDrawFrameClipX(GLuint *textures, unsigned frame, int x, int y) const;
-#endif
 	void DrawFrameClipX(unsigned frame, int x, int y) const;
 	void DrawFrameTransX(unsigned frame, int x, int y, int alpha) const;
 	void DrawFrameClipTransX(unsigned frame, int x, int y, int alpha) const;
@@ -98,18 +87,14 @@ public:
 	inline bool IsLoaded() { return Surface != NULL; }
 
 	//guichan
-#ifndef USE_OPENGL
 	virtual void *_getData() const { return Surface; }
-#endif
 	virtual int getWidth() const { return Width; }
 	virtual int getHeight() const { return Height; }
 
 	std::string File;          /// Filename
 	std::string HashFile;      /// Filename used in hash
 	SDL_Surface *Surface;      /// Surface
-#ifndef USE_OPENGL
 	SDL_Surface *SurfaceFlip;  /// Flipped surface
-#endif
 	int Width;                 /// Width of a frame
 	int Height;                /// Height of a frame
 	int NumFrames;             /// Number of frames
@@ -117,27 +102,21 @@ public:
 	int GraphicHeight;         /// Original graphic height
 	int Refs;                  /// Uses of this graphic
 	bool Resized;              /// Image has been resized
-#ifdef USE_OPENGL
 	GLfloat TextureWidth;      /// Width of the texture
 	GLfloat TextureHeight;     /// Height of the texture
 	GLuint *Textures;          /// Texture names
-	int NumTextures;
-#endif
+	int NumTextures;           /// Number of textures
 
-#ifdef USE_OPENGL
 	friend void MakeFontColorTextures(CFont *font);
 	friend void CleanFonts(void);
 	friend void ReloadFonts(void);
-#endif
 };
 
 class CPlayerColorGraphic : public CGraphic
 {
 protected:
 	CPlayerColorGraphic() {
-#ifdef USE_OPENGL
 		memset(PlayerColorTextures, 0, sizeof(PlayerColorTextures));
-#endif
 	}
 
 public:
@@ -147,9 +126,7 @@ public:
 	static CPlayerColorGraphic *New(const std::string &file, int w = 0, int h = 0);
 	static CPlayerColorGraphic *ForceNew(const std::string &file, int w = 0, int h = 0);
 
-#ifdef USE_OPENGL
 	GLuint *PlayerColorTextures[PlayerMax];/// Textures with player colors
-#endif
 };
 
 	/// A platform independent color
@@ -255,38 +232,39 @@ public:
 	void FillCircleClip(Uint32 color, int x, int y, int radius);
 	void FillTransCircleClip(Uint32 color, int x, int y, int radius, unsigned char alpha);
 
-#ifndef USE_OPENGL
 	inline Uint32 MapRGB(SDL_PixelFormat *f, Uint8 r, Uint8 g, Uint8 b) {
-		return SDL_MapRGB(f, r, g, b);
+		if (!UseOpenGL) {
+			return SDL_MapRGB(f, r, g, b);
+		} else {
+			return MapRGBA(f, r, g, b, 0xFF);
+		}
 	}
 	inline Uint32 MapRGBA(SDL_PixelFormat *f, Uint8 r, Uint8 g, Uint8 b, Uint8 a) {
-		return SDL_MapRGBA(f, r, g, b, a);
+		if (!UseOpenGL) {
+			return SDL_MapRGBA(f, r, g, b, a);
+		} else {
+			return (r | (g << 8) | (b << 16) | (a << 24));
+		}
 	}
 	inline void GetRGB(Uint32 c, SDL_PixelFormat *f, Uint8 *r, Uint8 *g, Uint8 *b) {
-		SDL_GetRGB(c, f, r, g, b);
+		if (!UseOpenGL) {
+			SDL_GetRGB(c, f, r, g, b);
+		} else {
+			*r = (c >> 0) & 0xff;
+			*g = (c >> 8) & 0xff;
+			*b = (c >> 16) & 0xff;
+		}
 	}
 	inline void GetRGBA(Uint32 c, SDL_PixelFormat *f, Uint8 *r, Uint8 *g, Uint8 *b, Uint8 *a) {
-		SDL_GetRGBA(c, f, r, g, b, a);
+		if (!UseOpenGL) {
+			SDL_GetRGBA(c, f, r, g, b, a);
+		} else {
+			*r = (c >> 0) & 0xff;
+			*g = (c >> 8) & 0xff;
+			*b = (c >> 16) & 0xff;
+			*a = (c >> 24) & 0xff;
+		}
 	}
-#else
-	inline Uint32 MapRGB(SDL_PixelFormat *f, Uint8 r, Uint8 g, Uint8 b) {
-		return MapRGBA(f, r, g, b, 0xFF);
-	}
-	inline Uint32 MapRGBA(SDL_PixelFormat *f, Uint8 r, Uint8 g, Uint8 b, Uint8 a) {
-		return (r | (g << 8) | (b << 16) | (a << 24));
-	}
-	inline void GetRGB(Uint32 c, Uint8 *r, Uint8 *g, Uint8 *b) {
-		*r = (c >> 0) & 0xff;
-		*g = (c >> 8) & 0xff;
-		*b = (c >> 16) & 0xff;
-	}
-	inline void GetRGBA(Uint32 c, Uint8 *r, Uint8 *g, Uint8 *b, Uint8 *a) {
-		*r = (c >> 0) & 0xff;
-		*g = (c >> 8) & 0xff;
-		*b = (c >> 16) & 0xff;
-		*a = (c >> 24) & 0xff;
-	}
-#endif
 
 	int Width;
 	int Height;
@@ -326,12 +304,10 @@ extern void SetPlayersPalette(void);
 	/// The SDL screen
 extern SDL_Surface *TheScreen;
 
-#ifdef USE_OPENGL
 	/// Max texture size supported on the video card
 extern GLint GLMaxTextureSize;
 	/// Is OpenGL texture compression supported
 extern bool GLTextureCompressionSupported;
-#endif
 	/// Use OpenGL texture compression
 extern bool UseGLTextureCompression;
 
@@ -356,19 +332,15 @@ extern int VideoValidResolution(int w, int h);
 	/// Load graphic from PNG file
 extern int LoadGraphicPNG(CGraphic *g);
 
-#ifdef USE_OPENGL
 	/// Make an OpenGL texture
 extern void MakeTexture(CGraphic *graphic);
 	/// Make an OpenGL texture of the player color pixels only.
 extern void MakePlayerColorTexture(CPlayerColorGraphic *graphic, int player);
-#endif
 
-#ifdef USE_OPENGL
 	/// Reload OpenGL graphics
 extern void ReloadGraphics(void);
 	/// Reload OpenGL
 extern void ReloadOpenGL();
-#endif
 
 	/// Initializes video synchronization.
 extern void SetVideoSync(void);
@@ -434,32 +406,13 @@ extern Uint32 ColorRed;
 extern Uint32 ColorGreen;
 extern Uint32 ColorYellow;
 
-#ifdef USE_OPENGL
 void DrawTexture(const CGraphic *g, GLuint *textures, int sx, int sy,
 	int ex, int ey, int x, int y, int flip);
-#endif
-
-#ifndef USE_OPENGL
-	/// Draw pixel unclipped.
-extern void (*VideoDrawPixel)(Uint32 color, int x, int y);
-
-	/// Draw translucent pixel unclipped.
-extern void (*VideoDrawTransPixel)(Uint32 color, int x, int y,
-	unsigned char alpha);
-#else
-	/// Draw pixel unclipped.
-extern void VideoDrawPixel(Uint32 color, int x, int y);
-
-	/// Draw translucent pixel unclipped.
-extern void VideoDrawTransPixel(Uint32 color, int x, int y,
-	unsigned char alpha);
-#endif
 
 #ifdef DEBUG
 extern void FreeGraphics();
 #endif
 
-#ifdef USE_OPENGL
 // ARB_texture_compression
 extern PFNGLCOMPRESSEDTEXIMAGE3DARBPROC    glCompressedTexImage3DARB;
 extern PFNGLCOMPRESSEDTEXIMAGE2DARBPROC    glCompressedTexImage2DARB;
@@ -468,7 +421,6 @@ extern PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC glCompressedTexSubImage3DARB;
 extern PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC glCompressedTexSubImage2DARB;
 extern PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC glCompressedTexSubImage1DARB;
 extern PFNGLGETCOMPRESSEDTEXIMAGEARBPROC   glGetCompressedTexImageARB;
-#endif
 
 //@}
 
