@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: commands.cpp 8588 2007-03-03 12:44:36Z feb $
+//      $Id: commands.cpp 8659 2007-04-02 00:29:29Z jim4 $
 
 //@{
 
@@ -184,7 +184,7 @@ static FullReplay *StartReplay(void)
 
 	replay->Comment1 = "Generated by Bos Wars Version " VERSION "";
 	replay->Comment2 = "Visit http://www.boswars.org for more information";
-	replay->Comment3 = "$Id: commands.cpp 8588 2007-03-03 12:44:36Z feb $";
+	replay->Comment3 = "$Id: commands.cpp 8659 2007-04-02 00:29:29Z jim4 $";
 
 	if (GameSettings.NetGameType == SettingsSinglePlayerGame) {
 		replay->Type = ReplaySinglePlayer;
@@ -839,20 +839,10 @@ static void DoNextReplay(void)
 		SendCommandDismiss(UnitSlots[unit]);
 	} else if (!strcmp(action, "resource")) {
 		SendCommandResource(UnitSlots[unit], dunit, flags);
-	} else if (!strcmp(action, "return")) {
-		SendCommandReturnGoods(UnitSlots[unit], dunit, flags);
 	} else if (!strcmp(action, "train")) {
 		SendCommandTrainUnit(UnitSlots[unit], UnitTypeByIdent(val), flags);
 	} else if (!strcmp(action, "cancel-train")) {
 		SendCommandCancelTraining(UnitSlots[unit], num, (val && *val) ? UnitTypeByIdent(val) : NULL);
-	} else if (!strcmp(action, "upgrade-to")) {
-		SendCommandUpgradeTo(UnitSlots[unit], UnitTypeByIdent(val), flags);
-	} else if (!strcmp(action, "cancel-upgrade-to")) {
-		SendCommandCancelUpgradeTo(UnitSlots[unit]);
-	} else if (!strcmp(action, "research")) {
-		SendCommandResearch(UnitSlots[unit], CUpgrade::Get(val), flags);
-	} else if (!strcmp(action, "cancel-research")) {
-		SendCommandCancelResearch(UnitSlots[unit]);
 	} else if (!strcmp(action, "spell-cast")) {
 		SendCommandSpellCast(UnitSlots[unit], posx, posy, dunit, num, flags);
 	} else if (!strcmp(action, "auto-spell-cast")) {
@@ -1211,23 +1201,6 @@ void SendCommandResource(CUnit *unit, CUnit *dest, int flush)
 	}
 }
 
-/**
-** Send command: Unit return goods.
-**
-** @param unit    pointer to unit.
-** @param goal    pointer to destination of the goods. (NULL=search best)
-** @param flush   Flag flush all pending commands.
-*/
-void SendCommandReturnGoods(CUnit *unit, CUnit *goal, int flush)
-{
-	if (!IsNetworkGame()) {
-		CommandLog("return", unit, flush, -1, -1, goal, NULL, -1);
-		CommandReturnGoods(unit, goal, flush);
-	} else {
-		NetworkSendCommand(MessageCommandReturn, unit, 0, 0, goal, 0, flush);
-	}
-}
-
 /**
 ** Send command: Building/unit train new unit.
 **
@@ -1264,74 +1237,6 @@ void SendCommandCancelTraining(CUnit *unit, int slot, const CUnitType *type)
 	}
 }
 
-/**
-** Send command: Building starts upgrading to.
-**
-** @param unit     pointer to unit.
-** @param what     pointer to unit-type of the unit upgrade.
-** @param flush    Flag flush all pending commands.
-*/
-void SendCommandUpgradeTo(CUnit *unit, CUnitType *what, int flush)
-{
-	if (!IsNetworkGame()) {
-		CommandLog("upgrade-to", unit, flush, -1, -1, NoUnitP, what->Ident.c_str(), -1);
-		CommandUpgradeTo(unit, what, flush);
-	} else {
-		NetworkSendCommand(MessageCommandUpgrade, unit, 0, 0, NoUnitP, what, flush);
-	}
-}
-
-/**
-** Send command: Cancel building upgrading to.
-**
-** @param unit  Pointer to unit.
-*/
-void SendCommandCancelUpgradeTo(CUnit *unit)
-{
-	if (!IsNetworkGame()) {
-		CommandLog("cancel-upgrade-to", unit, FlushCommands,
-			-1, -1, NoUnitP, NULL, -1);
-		CommandCancelUpgradeTo(unit);
-	} else {
-		NetworkSendCommand(MessageCommandCancelUpgrade, unit,
-			0, 0, NoUnitP, NULL, FlushCommands);
-	}
-}
-
-/**
-** Send command: Building/unit research.
-**
-** @param unit     pointer to unit.
-** @param what     research-type of the research.
-** @param flush    Flag flush all pending commands.
-*/
-void SendCommandResearch(CUnit *unit, CUpgrade *what, int flush)
-{
-	if (!IsNetworkGame()) {
-		CommandLog("research", unit, flush, -1, -1, NoUnitP, what->Ident.c_str(), -1);
-		CommandResearch(unit, what, flush);
-	} else {
-		NetworkSendCommand(MessageCommandResearch, unit,
-			what->ID, 0, NoUnitP, NULL, flush);
-	}
-}
-
-/**
-** Send command: Cancel Building/unit research.
-**
-** @param unit pointer to unit.
-*/
-void SendCommandCancelResearch(CUnit *unit)
-{
-	if (!IsNetworkGame()) {
-		CommandLog("cancel-research", unit, FlushCommands, -1, -1, NoUnitP, NULL, -1);
-		CommandCancelResearch(unit);
-	} else {
-		NetworkSendCommand(MessageCommandCancelResearch, unit,
-			0, 0, NoUnitP, NULL, FlushCommands);
-	}
-}
-
 /**
 ** Send command: Unit spell cast on position/unit.
 **
@@ -1578,15 +1483,6 @@ void ParseCommand(unsigned char msgnr, UnitRef unum,
 			CommandLog("resource", unit, status, -1, -1, dest, NULL, -1);
 			CommandResource(unit, dest, status);
 			break;
-		case MessageCommandReturn:
-			dest = NoUnitP;
-			if (dstnr != (unsigned short)0xFFFF) {
-				dest = UnitSlots[dstnr];
-				Assert(dest && dest->Type);
-			}
-			CommandLog("return", unit, status, -1, -1, dest, NULL, -1);
-			CommandReturnGoods(unit, dest, status);
-			break;
 		case MessageCommandTrain:
 			CommandLog("train", unit, status, -1, -1, NoUnitP,
 				UnitTypes[dstnr]->Ident.c_str(), -1);
@@ -1604,26 +1500,6 @@ void ParseCommand(unsigned char msgnr, UnitRef unum,
 				CommandCancelTraining(unit, (short)x, NULL);
 			}
 			break;
-		case MessageCommandUpgrade:
-			CommandLog("upgrade-to", unit, status, -1, -1, NoUnitP,
-				UnitTypes[dstnr]->Ident.c_str(), -1);
-			CommandUpgradeTo(unit, UnitTypes[dstnr], status);
-			break;
-		case MessageCommandCancelUpgrade:
-			CommandLog("cancel-upgrade-to", unit, FlushCommands, -1, -1, NoUnitP,
-				NULL, -1);
-			CommandCancelUpgradeTo(unit);
-			break;
-		case MessageCommandResearch:
-			CommandLog("research", unit, status, -1, -1, NoUnitP,
-				AllUpgrades[x]->Ident.c_str(), -1);
-			CommandResearch(unit, AllUpgrades[x], status);
-			break;
-		case MessageCommandCancelResearch:
-			CommandLog("cancel-research", unit, FlushCommands, -1, -1, NoUnitP,
-				NULL, -1);
-			CommandCancelResearch(unit);
-			break;
 		default:
 			id = (msgnr&0x7f) - MessageCommandSpellCast;
 			if (y != (unsigned short)0xFFFF) {
