@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: script.cpp 9000 2007-07-07 20:30:01Z jim4 $
+//      $Id: script.cpp 9075 2007-08-26 17:21:36Z jim4 $
 
 //@{
 
@@ -1345,7 +1345,7 @@ static int AliasUnitVar(lua_State *l, const char *s)
 	if (nargs >= 3) {
 		//  Warning: type is for unit->Stats->Var...
 		//           and Initial is for unit->Type->Var... (no upgrade modification)
-		char *sloc[] = {"Unit", "Initial", "Type", NULL};
+		const char *sloc[] = {"Unit", "Initial", "Type", NULL};
 		int i;
 		const char *key;
 
