@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: script_spell.cpp 8550 2007-02-10 12:33:10Z feb $
+//      $Id: script_spell.cpp 8612 2007-03-15 04:20:44Z jim4 $
 //@{
 
 /*----------------------------------------------------------------------------
@@ -749,12 +749,6 @@ static int CclDefineSpell(lua_State *l)
 			if (!spell->SoundWhenCast.Sound) {
 				spell->SoundWhenCast.Name.clear();
 			}
-		} else if (!strcmp(value, "depend-upgrade")) {
-			value = LuaToString(l, i + 1);
-			spell->DependencyId = UpgradeIdByIdent(value);
-			if (spell->DependencyId == -1) {
-				lua_pushfstring(l, "Bad upgrade name: %s", value);
-			}
 		} else {
 			LuaError(l, "Unsupported tag: %s" _C_ value);
 		}
