@@ -9,7 +9,7 @@
 //
 /**@name selection.cpp - The units' selection. */
 //
-//      (c) Copyright 1999-2005 by Patrice Fortier, Lutz Sammer, and
+//      (c) Copyright 1999-2007 by Patrice Fortier, Lutz Sammer, and
 //                                 Jimmy Salmon
 //
 //      This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: selection.cpp 8550 2007-02-10 12:33:10Z feb $
+//      $Id: selection.cpp 8681 2007-04-06 03:59:51Z jim4 $
 
 //@{
 
@@ -134,32 +134,6 @@ void UnSelectAll(void)
 
 }
 
-/**
-**  Handle a suicide unit click
-**
-**  @param unit  suicide unit.
-*/
-static void HandleSuicideClick(CUnit *unit)
-{
-	static int NumClicks = 0;
-
-	Assert(unit->Type->ClicksToExplode);
-	if (GameObserve) {
-		return;
-	}
-
-	if (NumSelected == 1 && Selected[0] == unit) {
-		NumClicks++;
-	} else {
-		NumClicks = 1;
-	}
-
-	if (NumClicks == unit->Type->ClicksToExplode) {
-		SendCommandDismiss(unit);
-		NumClicks = 0;
-	}
-}
-
 /**
 **  Replace a group of selected units by an other group of units.
 **
@@ -174,14 +148,6 @@ void ChangeSelectedUnits(CUnit **units,int count)
 
 	Assert(count <= MaxSelectable);
 
-	if (count == 1 && units[0]->Type->ClicksToExplode &&
-		!units[0]->Type->IsNotSelectable) {
-		HandleSuicideClick(units[0]);
-		if (units[0]->Orders[0]->Action == UnitActionDie) {
-			NetworkSendSelection(units, count);
-			return ;
-		}
-	}
 	UnSelectAll();
 	NetworkSendSelection(units, count);
 	for (n = i = 0; i < count; ++i) {
@@ -398,10 +364,6 @@ int SelectUnitsByType(CUnit *base)
 	r = UnitCacheSelect(vp->MapX - 1, vp->MapY - 1, vp->MapX + vp->MapWidth + 1,
 		vp->MapY + vp->MapHeight + 1, table);
 
-	if (base->Type->ClicksToExplode) {
-		HandleSuicideClick(base);
-	}
-
 	// if unit is a cadaver or hidden (not on map)
 	// no unit can be selected.
 	if (base->Removed || base->Orders[0]->Action == UnitActionDie) {
@@ -820,7 +782,7 @@ int SelectUnitsInRectangle (int sx0, int sy0, int sx1, int sy1)
 		if (type->Building && !unit->IsVisibleOnMap(ThisPlayer)) {
 			continue;
 		}
-		if ((type->GivesResource && !unit->Removed)) { // no built resources.
+		if ((type->CanHarvestFrom && !unit->Removed)) { // no built resources.
 			SelectSingleUnit(unit);
 			return 1;
 		}
@@ -1132,7 +1094,7 @@ void InitSelections(void)
 void SaveSelections(CFile *file)
 {
 	file->printf("\n--- -----------------------------------------\n");
-	file->printf("--- MODULE: selection $Id: selection.cpp 8550 2007-02-10 12:33:10Z feb $\n\n");
+	file->printf("--- MODULE: selection $Id: selection.cpp 8681 2007-04-06 03:59:51Z jim4 $\n\n");
 
 	file->printf("SetGroupId(%d)\n", GroupId);
 	file->printf("Selection(%d, {", NumSelected);
