@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: mouse.cpp 8964 2007-06-30 20:17:02Z jim4 $
+//      $Id: mouse.cpp 9075 2007-08-26 17:21:36Z jim4 $
 
 //@{
 
@@ -1822,7 +1822,6 @@ void DrawPieMenu(void)
 	const ButtonAction *buttons;
 	CViewport *vp;
 	CPlayer *player;
-	char buf[2] = "?";
 
 	if (CursorState != CursorStatePieMenu)
 		return;
@@ -1856,13 +1855,12 @@ void DrawPieMenu(void)
 
 			// Tutorial show command key in icons
 			if (UI.ButtonPanel.ShowCommandKey) {
-				char *text;
+				std::string text("?");
 
 				if (CurrentButtons[i].Key == 27) {
 					text = "ESC";
 				} else {
-					buf[0] = toupper(CurrentButtons[i].Key);
-					text = buf;
+					text[0] = toupper(CurrentButtons[i].Key);
 				}
 				VideoDrawTextClip(x + 4, y + 4, GameFont, text);
 			}
