@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: unit.cpp 9029 2007-08-04 15:17:16Z feb $
+//      $Id: unit.cpp 9074 2007-08-26 07:42:45Z jim4 $
 
 //@{
 
@@ -3378,6 +3378,7 @@ void SaveUnit(const CUnit *unit, CFile *file)
 	}
 
 	file->printf("\"tile\", {%d, %d}, ", unit->X, unit->Y);
+	file->printf("\"seen-tile\", {%d, %d}, ", unit->Seen.X, unit->Seen.Y);
 	file->printf("\"refs\", %d, ", unit->Refs);
 #if 0
 	// latimerius: why is this so complex?
@@ -3447,6 +3448,17 @@ void SaveUnit(const CUnit *unit, CFile *file)
 	if (unit->Seen.Constructed) {
 		file->printf(" \"seen-constructed\",");
 	}
+
+	if (unit->Seen.CFrame) {
+		CConstructionFrame *cframe = unit->Type->Construction->Frames;
+		int frame = 0;
+		while (cframe != unit->Seen.CFrame) {
+			cframe = cframe->Next;
+			++frame;
+		}
+		file->printf(" \"seen-cframe\", %d,", frame);
+	}
+
 	file->printf(" \"seen-state\", %d, ", unit->Seen.State);
 	file->printf("\"ttl\", %lu, ", unit->TTL);
 
@@ -3610,7 +3622,7 @@ void SaveUnits(CFile *file)
 	CUnit *unit;
 
 	file->printf("\n--- -----------------------------------------\n");
-	file->printf("--- MODULE: units $Id: unit.cpp 9029 2007-08-04 15:17:16Z feb $\n\n");
+	file->printf("--- MODULE: units $Id: unit.cpp 9074 2007-08-26 07:42:45Z jim4 $\n\n");
 
 	file->printf("-- Unit slot usage bitmap\n");
 	file->printf("SlotUsage(%d", UnitSlotFree);
