@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: graphic.cpp 8949 2007-06-29 11:25:27Z Jarod42 $
+//      $Id: graphic.cpp 9053 2007-08-19 07:47:27Z jim4 $
 
 //@{
 
@@ -57,9 +57,7 @@ static int HashCount;
 
 static std::map<std::string, CGraphic *> GraphicHash;
 
-#ifdef USE_OPENGL
 static std::list<CGraphic *> Graphics;
-#endif
 
 /*----------------------------------------------------------------------------
 --  Functions
@@ -77,14 +75,14 @@ static std::list<CGraphic *> Graphics;
 */
 void CGraphic::DrawSub(int gx, int gy, int w, int h, int x, int y) const
 {
-#ifndef USE_OPENGL
-	SDL_Rect srect = {gx, gy, w, h};
-	SDL_Rect drect = {x, y, 0, 0};
+	if (!UseOpenGL) {
+		SDL_Rect srect = {gx, gy, w, h};
+		SDL_Rect drect = {x, y, 0, 0};
 
-	SDL_BlitSurface(Surface, &srect, TheScreen, &drect);
-#else
-	DrawTexture(this, Textures, gx, gy, gx + w, gy + h, x, y, 0);
-#endif
+		SDL_BlitSurface(Surface, &srect, TheScreen, &drect);
+	} else {
+		DrawTexture(this, Textures, gx, gy, gx + w, gy + h, x, y, 0);
+	}
 }
 
 /**
@@ -119,17 +117,17 @@ void CGraphic::DrawSubClip(int gx, int gy, int w, int h, int x, int y) const
 void CGraphic::DrawSubTrans(int gx, int gy, int w, int h, int x, int y,
 	unsigned char alpha) const
 {
-#ifndef USE_OPENGL
-	int oldalpha = Surface->format->alpha;
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
-	DrawSub(gx, gy, w, h, x, y);
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
-#else
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub(255, 255, 255, alpha);
-	DrawSub(gx, gy, w, h, x, y);
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
+	if (!UseOpenGL) {
+		int oldalpha = Surface->format->alpha;
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
+		DrawSub(gx, gy, w, h, x, y);
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
+	} else {
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glColor4ub(255, 255, 255, alpha);
+		DrawSub(gx, gy, w, h, x, y);
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	}
 }
 
 /**
@@ -161,23 +159,22 @@ void CGraphic::DrawSubClipTrans(int gx, int gy, int w, int h, int x, int y,
 */
 void CGraphic::DrawFrame(unsigned frame, int x, int y) const
 {
-#ifndef USE_OPENGL
-	DrawSub((frame % (Surface->w / Width)) * Width,
-		(frame / (Surface->w / Width)) * Height,
-		Width, Height, x, y);
-#else
-	int sx, sy, ex, ey, n;
+	if (!UseOpenGL) {
+		DrawSub((frame % (Surface->w / Width)) * Width,
+			(frame / (Surface->w / Width)) * Height,
+			Width, Height, x, y);
+	} else {
+		int sx, sy, ex, ey, n;
 
-	n = GraphicWidth / Width;
-	sx = (frame % n) * Width;
-	ex = sx + Width;
-	sy = (frame / n) * Height;
-	ey = sy + Height;
-	DrawTexture(this, Textures, sx, sy, ex, ey, x, y, 0);
-#endif
+		n = GraphicWidth / Width;
+		sx = (frame % n) * Width;
+		ex = sx + Width;
+		sy = (frame / n) * Height;
+		ey = sy + Height;
+		DrawTexture(this, Textures, sx, sy, ex, ey, x, y, 0);
+	}
 }
 
-#ifdef USE_OPENGL
 void CGraphic::DoDrawFrameClip(GLuint *textures,
 	unsigned frame, int x, int y) const
 {
@@ -200,7 +197,6 @@ void CGraphic::DoDrawFrameClip(GLuint *textures,
 
 	DrawTexture(this, textures, sx + ox, sy + oy, sx + ox + w, sy + oy + h, x, y, 0);
 }
-#endif
 
 /**
 **  Draw graphic object clipped.
@@ -211,41 +207,41 @@ void CGraphic::DoDrawFrameClip(GLuint *textures,
 */
 void CGraphic::DrawFrameClip(unsigned frame, int x, int y) const
 {
-#ifndef USE_OPENGL
-	DrawSubClip((frame % (Surface->w / Width)) * Width,
-		(frame / (Surface->w / Width)) * Height,
-		Width, Height, x, y);
-#else
-	DoDrawFrameClip(Textures, frame, x, y);
-#endif
+	if (!UseOpenGL) {
+		DrawSubClip((frame % (Surface->w / Width)) * Width,
+			(frame / (Surface->w / Width)) * Height,
+			Width, Height, x, y);
+	} else {
+		DoDrawFrameClip(Textures, frame, x, y);
+	}
 }
 
 void CGraphic::DrawFrameTrans(unsigned frame, int x, int y, int alpha) const
 {
-#ifndef USE_OPENGL
-	DrawSubTrans((frame % (Surface->w / Width)) * Width,
-		(frame / (Surface->w / Width)) * Height,
-		Width, Height, x, y, alpha);
-#else
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub(255, 255, 255, alpha);
-	DrawFrame(frame, x, y);
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
+	if (!UseOpenGL) {
+		DrawSubTrans((frame % (Surface->w / Width)) * Width,
+			(frame / (Surface->w / Width)) * Height,
+			Width, Height, x, y, alpha);
+	} else {
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glColor4ub(255, 255, 255, alpha);
+		DrawFrame(frame, x, y);
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	}
 }
 
 void CGraphic::DrawFrameClipTrans(unsigned frame, int x, int y, int alpha) const
 {
-#ifndef USE_OPENGL
-	DrawSubClipTrans((frame % (Surface->w / Width)) * Width,
-		(frame / (Surface->w / Width)) * Height,
-		Width, Height, x, y, alpha);
-#else
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub(255, 255, 255, alpha);
-	DrawFrameClip(frame, x, y);
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
+	if (!UseOpenGL) {
+		DrawSubClipTrans((frame % (Surface->w / Width)) * Width,
+			(frame / (Surface->w / Width)) * Height,
+			Width, Height, x, y, alpha);
+	} else {
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glColor4ub(255, 255, 255, alpha);
+		DrawFrameClip(frame, x, y);
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	}
 }
 
 /**
@@ -259,15 +255,15 @@ void CGraphic::DrawFrameClipTrans(unsigned frame, int x, int y, int alpha) const
 void CPlayerColorGraphic::DrawPlayerColorFrameClip(int player, unsigned frame,
 	int x, int y)
 {
-#ifndef USE_OPENGL
-	GraphicPlayerPixels(&Players[player], this);
-	DrawFrameClip(frame, x, y);
-#else
-	if (!PlayerColorTextures[player]) {
-		MakePlayerColorTexture(this, player);
+	if (!UseOpenGL) {
+		GraphicPlayerPixels(&Players[player], this);
+		DrawFrameClip(frame, x, y);
+	} else {
+		if (!PlayerColorTextures[player]) {
+			MakePlayerColorTexture(this, player);
+		}
+		DoDrawFrameClip(PlayerColorTextures[player], frame, x, y);
 	}
-	DoDrawFrameClip(PlayerColorTextures[player], frame, x, y);
-#endif
 }
 
 
@@ -281,33 +277,32 @@ void CPlayerColorGraphic::DrawPlayerColorFrameClip(int player, unsigned frame,
 */
 void CGraphic::DrawFrameX(unsigned frame, int x, int y) const
 {
-#ifndef USE_OPENGL
-	SDL_Rect srect;
-	SDL_Rect drect;
+	if (!UseOpenGL) {
+		SDL_Rect srect;
+		SDL_Rect drect;
 
-	srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
-		Width)) * Width) - Width;
-	srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
-	srect.w = Width;
-	srect.h = Height;
+		srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
+			Width)) * Width) - Width;
+		srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
+		srect.w = Width;
+		srect.h = Height;
 
-	drect.x = x;
-	drect.y = y;
+		drect.x = x;
+		drect.y = y;
 
-	SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
-#else
-	int sx, sy, ex, ey, n;
+		SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
+	} else {
+		int sx, sy, ex, ey, n;
 
-	n = GraphicWidth / Width;
-	sx = (frame % n) * Width;
-	ex = sx + Width;
-	sy = (frame / n) * Height;
-	ey = sy + Height;
-	DrawTexture(this, Textures, sx, sy, ex, ey, x, y, 1);
-#endif
+		n = GraphicWidth / Width;
+		sx = (frame % n) * Width;
+		ex = sx + Width;
+		sy = (frame / n) * Height;
+		ey = sy + Height;
+		DrawTexture(this, Textures, sx, sy, ex, ey, x, y, 1);
+	}
 }
 
-#ifdef USE_OPENGL
 void CGraphic::DoDrawFrameClipX(GLuint *textures, unsigned frame,
 	int x, int y) const
 {
@@ -338,7 +333,6 @@ void CGraphic::DoDrawFrameClipX(GLuint *textures, unsigned frame,
 
 	DrawTexture(this, textures, sx + ox, sy + oy, sx + ox + w, sy + oy + h, x, y, 1);
 }
-#endif
 
 /**
 **  Draw graphic object clipped and flipped in X direction.
@@ -349,95 +343,95 @@ void CGraphic::DoDrawFrameClipX(GLuint *textures, unsigned frame,
 */
 void CGraphic::DrawFrameClipX(unsigned frame, int x, int y) const
 {
-#ifndef USE_OPENGL
-	SDL_Rect srect;
-	SDL_Rect drect;
-	int oldx;
-	int oldy;
+	if (!UseOpenGL) {
+		SDL_Rect srect;
+		SDL_Rect drect;
+		int oldx;
+		int oldy;
 
-	srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
-			Width)) * Width) - Width;
-	srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
-	srect.w = Width;
-	srect.h = Height;
+		srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
+				Width)) * Width) - Width;
+		srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
+		srect.w = Width;
+		srect.h = Height;
 
-	oldx = x;
-	oldy = y;
-	CLIP_RECTANGLE(x, y, srect.w, srect.h);
-	srect.x += x - oldx;
-	srect.y += y - oldy;
+		oldx = x;
+		oldy = y;
+		CLIP_RECTANGLE(x, y, srect.w, srect.h);
+		srect.x += x - oldx;
+		srect.y += y - oldy;
 
-	drect.x = x;
-	drect.y = y;
+		drect.x = x;
+		drect.y = y;
 
-	SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
-#else
-	DoDrawFrameClipX(Textures, frame, x, y);
-#endif
+		SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
+	} else {
+		DoDrawFrameClipX(Textures, frame, x, y);
+	}
 }
 
 void CGraphic::DrawFrameTransX(unsigned frame, int x, int y, int alpha) const
 {
-#ifndef USE_OPENGL
-	SDL_Rect srect;
-	SDL_Rect drect;
-	int oldalpha;
+	if (!UseOpenGL) {
+		SDL_Rect srect;
+		SDL_Rect drect;
+		int oldalpha;
 
-	srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
-		Width)) * Width) - Width;
-	srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
-	srect.w = Width;
-	srect.h = Height;
+		srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
+			Width)) * Width) - Width;
+		srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
+		srect.w = Width;
+		srect.h = Height;
 
-	drect.x = x;
-	drect.y = y;
+		drect.x = x;
+		drect.y = y;
 
-	oldalpha = Surface->format->alpha;
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
-	SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
-#else
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub(255, 255, 255, alpha);
-	DrawFrameX(frame, x, y);
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
+		oldalpha = Surface->format->alpha;
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
+		SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
+	} else {
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glColor4ub(255, 255, 255, alpha);
+		DrawFrameX(frame, x, y);
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	}
 }
 
 void CGraphic::DrawFrameClipTransX(unsigned frame, int x, int y, int alpha) const
 {
-#ifndef USE_OPENGL
-	SDL_Rect srect;
-	SDL_Rect drect;
-	int oldx;
-	int oldy;
-	int oldalpha;
+	if (!UseOpenGL) {
+		SDL_Rect srect;
+		SDL_Rect drect;
+		int oldx;
+		int oldy;
+		int oldalpha;
 
-	srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
-		Width)) * Width) - Width;
-	srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
-	srect.w = Width;
-	srect.h = Height;
+		srect.x = (SurfaceFlip->w - (frame % (SurfaceFlip->w /
+			Width)) * Width) - Width;
+		srect.y = (frame / (SurfaceFlip->w / Width)) * Height;
+		srect.w = Width;
+		srect.h = Height;
 
-	oldx = x;
-	oldy = y;
-	CLIP_RECTANGLE(x, y, srect.w, srect.h);
-	srect.x += x - oldx;
-	srect.y += y - oldy;
+		oldx = x;
+		oldy = y;
+		CLIP_RECTANGLE(x, y, srect.w, srect.h);
+		srect.x += x - oldx;
+		srect.y += y - oldy;
 
-	drect.x = x;
-	drect.y = y;
+		drect.x = x;
+		drect.y = y;
 
-	oldalpha = Surface->format->alpha;
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
-	SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
-	SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
-#else
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-	glColor4ub(255, 255, 255, alpha);
-	DrawFrameClipX(frame, x, y);
-	glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-#endif
+		oldalpha = Surface->format->alpha;
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, alpha);
+		SDL_BlitSurface(SurfaceFlip, &srect, TheScreen, &drect);
+		SDL_SetAlpha(Surface, SDL_SRCALPHA, oldalpha);
+	} else {
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+		glColor4ub(255, 255, 255, alpha);
+		DrawFrameClipX(frame, x, y);
+		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	}
 }
 
 /**
@@ -451,15 +445,15 @@ void CGraphic::DrawFrameClipTransX(unsigned frame, int x, int y, int alpha) cons
 void CPlayerColorGraphic::DrawPlayerColorFrameClipX(int player, unsigned frame,
 	int x, int y)
 {
-#ifndef USE_OPENGL
-	GraphicPlayerPixels(&Players[player], this);
-	DrawFrameClipX(frame, x, y);
-#else
-	if (!PlayerColorTextures[player]) {
-		MakePlayerColorTexture(this, player);
+	if (!UseOpenGL) {
+		GraphicPlayerPixels(&Players[player], this);
+		DrawFrameClipX(frame, x, y);
+	} else {
+		if (!PlayerColorTextures[player]) {
+			MakePlayerColorTexture(this, player);
+		}
+		DoDrawFrameClipX(PlayerColorTextures[player], frame, x, y);
 	}
-	DoDrawFrameClipX(PlayerColorTextures[player], frame, x, y);
-#endif
 }
 
 /*----------------------------------------------------------------------------
@@ -629,10 +623,32 @@ void CGraphic::Load()
 
 	NumFrames = GraphicWidth / Width * GraphicHeight / Height;
 
-#ifdef USE_OPENGL
-	MakeTexture(this);
-	Graphics.push_back(this);
-#endif
+	if (UseOpenGL) {
+		MakeTexture(this);
+		Graphics.push_back(this);
+	}
+}
+
+/**
+**  Free a SDL surface
+**
+**  @param surface  SDL surface to free
+*/
+static void FreeSurface(SDL_Surface **surface)
+{
+	if (!*surface) {
+		return;
+	}
+
+	unsigned char *pixels = NULL;
+
+	if ((*surface)->flags & SDL_PREALLOC) {
+		pixels = (unsigned char *)(*surface)->pixels;
+	}
+
+	SDL_FreeSurface(*surface);
+	delete[] pixels;
+	*surface = NULL;
 }
 
 /**
@@ -642,11 +658,6 @@ void CGraphic::Load()
 */
 void CGraphic::Free(CGraphic *g)
 {
-#ifdef USE_OPENGL
-	int i;
-#endif
-	unsigned char *pixels;
-
 	if (!g) {
 		return;
 	}
@@ -656,44 +667,26 @@ void CGraphic::Free(CGraphic *g)
 	--g->Refs;
 	if (!g->Refs) {
 		// No more uses of this graphic
-#ifdef USE_OPENGL
-		if (g->Textures) {
-			glDeleteTextures(g->NumTextures, g->Textures);
-			delete[] g->Textures;
-		}
-		CPlayerColorGraphic *cg = dynamic_cast<CPlayerColorGraphic *>(g);
-		if (cg) {
-			for (i = 0; i < PlayerMax; ++i) {
-				if (cg->PlayerColorTextures[i]) {
-					glDeleteTextures(cg->NumTextures, cg->PlayerColorTextures[i]);
-					delete[] cg->PlayerColorTextures[i];
+		if (UseOpenGL) {
+			if (g->Textures) {
+				glDeleteTextures(g->NumTextures, g->Textures);
+				delete[] g->Textures;
+			}
+			CPlayerColorGraphic *cg = dynamic_cast<CPlayerColorGraphic *>(g);
+			if (cg) {
+				for (int i = 0; i < PlayerMax; ++i) {
+					if (cg->PlayerColorTextures[i]) {
+						glDeleteTextures(cg->NumTextures, cg->PlayerColorTextures[i]);
+						delete[] cg->PlayerColorTextures[i];
+					}
 				}
 			}
+
+			Graphics.remove(g);
 		}
 
-		Graphics.remove(g);
-#endif
-
-		if (g->Surface) {
-			if (g->Surface->flags & SDL_PREALLOC) {
-				pixels = (unsigned char *)g->Surface->pixels;
-			} else {
-				pixels = NULL;
-			}
-			SDL_FreeSurface(g->Surface);
-			delete[] pixels;
-		}
-#ifndef USE_OPENGL
-		if (g->SurfaceFlip) {
-			if (g->SurfaceFlip->flags & SDL_PREALLOC) {
-				pixels = (unsigned char *)g->SurfaceFlip->pixels;
-			} else {
-				pixels = NULL;
-			}
-			SDL_FreeSurface(g->SurfaceFlip);
-			delete[] pixels;
-		}
-#endif
+		FreeSurface(&g->Surface);
+		FreeSurface(&g->SurfaceFlip);
 
 		if (!g->HashFile.empty()) {
 			GraphicHash.erase(g->HashFile);
@@ -702,7 +695,6 @@ void CGraphic::Free(CGraphic *g)
 	}
 }
 
-#ifdef USE_OPENGL
 /**
 **  Reload OpenGL graphics
 */
@@ -727,16 +719,16 @@ void ReloadGraphics(void)
 		}
 	}
 }
-#endif
 
 /**
 **  Flip graphic and store in graphic->SurfaceFlip
 */
 void CGraphic::Flip()
 {
-#ifdef USE_OPENGL
-	return;
-#else
+	if (UseOpenGL) {
+		return;
+	}
+
 	int i;
 	int j;
 	SDL_Surface *s;
@@ -781,10 +773,8 @@ void CGraphic::Flip()
 	}
 	SDL_UnlockSurface(Surface);
 	SDL_UnlockSurface(s);
-#endif
 }
 
-#ifdef USE_OPENGL
 /**
 **  Find the next power of 2 >= x
 */
@@ -1003,7 +993,6 @@ void MakePlayerColorTexture(CPlayerColorGraphic *g, int player)
 
 	MakeTextures(g, player, &Players[player].UnitColors);
 }
-#endif
 
 /**
 **  Resize a graphic
@@ -1029,30 +1018,10 @@ void CGraphic::Resize(int w, int h)
 	// Resizing the same image multiple times looks horrible
 	// If the image has already been resized then get a clean copy first
 	if (Resized) {
-		if (Surface) {
-			if (Surface->flags & SDL_PREALLOC) {
-				pixels = (unsigned char *)Surface->pixels;
-			} else {
-				pixels = NULL;
-			}
-			SDL_FreeSurface(Surface);
-			delete[] pixels;
-		}
-#ifndef USE_OPENGL
-		if (SurfaceFlip) {
-			if (SurfaceFlip->flags & SDL_PREALLOC) {
-				pixels = (unsigned char *)SurfaceFlip->pixels;
-			} else {
-				pixels = NULL;
-			}
-			SDL_FreeSurface(SurfaceFlip);
-			delete[] pixels;
-		}
-		SurfaceFlip = NULL;
-#endif
+		FreeSurface(&Surface);
+		FreeSurface(&SurfaceFlip);
 
 		this->Width = this->Height = 0;
-		this->Surface = NULL;
 		this->Load();
 
 		Resized = false;
@@ -1171,12 +1140,12 @@ void CGraphic::Resize(int w, int h)
 	Width = GraphicWidth = w;
 	Height = GraphicHeight = h;
 
-#ifdef USE_OPENGL
-	glDeleteTextures(NumTextures, Textures);
-	delete[] Textures;
-	Textures = NULL;
-	MakeTexture(this);
-#endif
+	if (UseOpenGL) {
+		glDeleteTextures(NumTextures, Textures);
+		delete[] Textures;
+		Textures = NULL;
+		MakeTexture(this);
+	}
 }
 
 /**
@@ -1230,20 +1199,20 @@ void CGraphic::MakeShadow()
 	SDL_SetPalette(Surface, SDL_LOGPAL | SDL_PHYSPAL, colors, 0, 256);
 	SDL_SetAlpha(Surface, SDL_SRCALPHA | SDL_RLEACCEL, 128);
 
-#ifndef USE_OPENGL
-	if (SurfaceFlip) {
-		SDL_SetPalette(SurfaceFlip, SDL_LOGPAL | SDL_PHYSPAL, colors, 0, 256);
-		SDL_SetAlpha(SurfaceFlip, SDL_SRCALPHA | SDL_RLEACCEL, 128);
+	if (!UseOpenGL) {
+		if (SurfaceFlip) {
+			SDL_SetPalette(SurfaceFlip, SDL_LOGPAL | SDL_PHYSPAL, colors, 0, 256);
+			SDL_SetAlpha(SurfaceFlip, SDL_SRCALPHA | SDL_RLEACCEL, 128);
+		}
 	}
-#endif
-#ifdef USE_OPENGL
-	if (Textures) {
-		glDeleteTextures(NumTextures, Textures);
-		delete[] Textures;
-		Textures = NULL;
+	if (UseOpenGL) {
+		if (Textures) {
+			glDeleteTextures(NumTextures, Textures);
+			delete[] Textures;
+			Textures = NULL;
+		}
+		MakeTexture(this);
 	}
-	MakeTexture(this);
-#endif
 }
 
 #ifdef DEBUG
