@@ -25,7 +25,7 @@
 //      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 //      02111-1307, USA.
 //
-//      $Id: sdl.cpp 8913 2007-06-23 19:08:26Z jim4 $
+//      $Id: sdl.cpp 9050 2007-08-18 23:16:46Z jim4 $
 
 //@{
 
@@ -77,13 +77,10 @@
 
 SDL_Surface *TheScreen; /// Internal screen
 
-#ifndef USE_OPENGL
 static SDL_Rect Rects[100];
 static int NumRects;
-#else
 GLint GLMaxTextureSize;             /// Max texture size supported on the video card
 bool GLTextureCompressionSupported; /// Is OpenGL texture compression supported
-#endif
 bool UseGLTextureCompression;       /// Use OpenGL texture compression
 
 static std::map<int, std::string> Key2Str;
@@ -98,7 +95,6 @@ const EventCallback *Callbacks;
 --  Functions
 ----------------------------------------------------------------------------*/
 
-#ifdef USE_OPENGL
 // ARB_texture_compression
 PFNGLCOMPRESSEDTEXIMAGE3DARBPROC    glCompressedTexImage3DARB;
 PFNGLCOMPRESSEDTEXIMAGE2DARBPROC    glCompressedTexImage2DARB;
@@ -107,7 +103,6 @@ PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC glCompressedTexSubImage3DARB;
 PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC glCompressedTexSubImage2DARB;
 PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC glCompressedTexSubImage1DARB;
 PFNGLGETCOMPRESSEDTEXIMAGEARBPROC   glGetCompressedTexImageARB;
-#endif
 
 /*----------------------------------------------------------------------------
 --  Sync
@@ -143,7 +138,6 @@ void SetVideoSync(void)
 --  Video
 ----------------------------------------------------------------------------*/
 
-#ifdef USE_OPENGL
 /**
 **  Check if an extension is supported
 */
@@ -253,7 +247,6 @@ void ReloadOpenGL()
 	ReloadFonts();
 	UI.Minimap.Reload();
 }
-#endif
 
 #if defined(DEBUG) && !defined(USE_WIN32)
 static void CleanExit(int signum)
@@ -404,9 +397,9 @@ void InitVideoSdl(void)
 	if (Video.FullScreen) {
 		flags |= SDL_FULLSCREEN;
 	}
-#ifdef USE_OPENGL
-	flags |= SDL_OPENGL;
-#endif
+	if (UseOpenGL) {
+		flags |= SDL_OPENGL;
+	}
 
 	if (!Video.Width || !Video.Height) {
 		Video.Width = 640;
@@ -434,9 +427,9 @@ void InitVideoSdl(void)
 	// Make default character translation easier
 	SDL_EnableUNICODE(1);
 
-#ifdef USE_OPENGL
-	InitOpenGL();
-#endif
+	if (UseOpenGL) {
+		InitOpenGL();
+	}
 
 	InitKey2Str();
 
@@ -474,15 +467,15 @@ int VideoValidResolution(int w, int h)
 */
 void InvalidateArea(int x, int y, int w, int h)
 {
-#ifndef USE_OPENGL
-	Assert(NumRects != sizeof(Rects) / sizeof(*Rects));
-	Assert(x >= 0 && y >= 0 && x + w <= Video.Width && y + h <= Video.Height);
-	Rects[NumRects].x = x;
-	Rects[NumRects].y = y;
-	Rects[NumRects].w = w;
-	Rects[NumRects].h = h;
-	++NumRects;
-#endif
+	if (!UseOpenGL) {
+		Assert(NumRects != sizeof(Rects) / sizeof(*Rects));
+		Assert(x >= 0 && y >= 0 && x + w <= Video.Width && y + h <= Video.Height);
+		Rects[NumRects].x = x;
+		Rects[NumRects].y = y;
+		Rects[NumRects].w = w;
+		Rects[NumRects].h = h;
+		++NumRects;
+	}
 }
 
 /**
@@ -490,13 +483,13 @@ void InvalidateArea(int x, int y, int w, int h)
 */
 void Invalidate(void)
 {
-#ifndef USE_OPENGL
-	Rects[0].x = 0;
-	Rects[0].y = 0;
-	Rects[0].w = Video.Width;
-	Rects[0].h = Video.Height;
-	NumRects = 1;
-#endif
+	if (!UseOpenGL) {
+		Rects[0].x = 0;
+		Rects[0].y = 0;
+		Rects[0].w = Video.Width;
+		Rects[0].h = Video.Height;
+		NumRects = 1;
+	}
 }
 
 /**
@@ -560,9 +553,9 @@ static void SdlDoEvent(const EventCallback *callbacks, const SDL_Event *event)
 						DoTogglePause = false;
 						UiTogglePause();
 					}
-#ifdef USE_OPENGL
-					Video.ResizeScreen(Video.Width, Video.Height);
-#endif
+					if (UseOpenGL) {
+						Video.ResizeScreen(Video.Width, Video.Height);
+					}
 				}
 			}
 			break;
@@ -725,9 +718,9 @@ void WaitEventsOneFrame()
 		SkipGameCycle = SkipFrames;
 	}
 
-#ifndef USE_OPENGL
-	Video.ClearScreen();
-#endif
+	if (!UseOpenGL) {
+		Video.ClearScreen();
+	}
 }
 
 /**
@@ -735,15 +728,15 @@ void WaitEventsOneFrame()
 */
 void RealizeVideoMemory(void)
 {
-#ifdef USE_OPENGL
-	SDL_GL_SwapBuffers();
-	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-#else
-	if (NumRects) {
-		SDL_UpdateRects(TheScreen, NumRects, Rects);
-		NumRects = 0;
+	if (UseOpenGL) {
+		SDL_GL_SwapBuffers();
+		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	} else {
+		if (NumRects) {
+			SDL_UpdateRects(TheScreen, NumRects, Rects);
+			NumRects = 0;
+		}
 	}
-#endif
 }
 
 /**
@@ -751,11 +744,11 @@ void RealizeVideoMemory(void)
 */
 void SdlLockScreen(void)
 {
-#ifndef USE_OPENGL
-	if (SDL_MUSTLOCK(TheScreen)) {
-		SDL_LockSurface(TheScreen);
+	if (!UseOpenGL) {
+		if (SDL_MUSTLOCK(TheScreen)) {
+			SDL_LockSurface(TheScreen);
+		}
 	}
-#endif
 }
 
 /**
@@ -763,11 +756,11 @@ void SdlLockScreen(void)
 */
 void SdlUnlockScreen(void)
 {
-#ifndef USE_OPENGL
-	if (SDL_MUSTLOCK(TheScreen)) {
-		SDL_UnlockSurface(TheScreen);
+	if (!UseOpenGL) {
+		if (SDL_MUSTLOCK(TheScreen)) {
+			SDL_UnlockSurface(TheScreen);
+		}
 	}
-#endif
 }
 
 /**
@@ -828,11 +821,9 @@ void ToggleFullScreen(void)
 	int w;
 	int h;
 	int bpp;
-#ifndef USE_OPENGL
-	unsigned char *pixels;
-	SDL_Color *palette;
-	int ncolors;
-#endif
+	unsigned char *pixels = NULL;
+	SDL_Color *palette = NULL;
+	int ncolors = 0;
 
 	if (!TheScreen) { // don't bother if there's no surface.
 		return;
@@ -852,38 +843,33 @@ void ToggleFullScreen(void)
 	// save the contents of the screen.
 	framesize = w * h * TheScreen->format->BytesPerPixel;
 
-#ifndef USE_OPENGL
-	if (!(pixels = new unsigned char[framesize])) { // out of memory
-		return;
-	}
-	SDL_LockSurface(TheScreen);
-	memcpy(pixels, TheScreen->pixels, framesize);
-
-#ifdef DEBUG
-	// shut up compiler
-	palette = NULL;
-	ncolors=0;
-#endif
-	if (TheScreen->format->palette) {
-		ncolors = TheScreen->format->palette->ncolors;
-		if (!(palette = new SDL_Color[ncolors])) {
-			delete[] pixels;
+	if (!UseOpenGL) {
+		if (!(pixels = new unsigned char[framesize])) { // out of memory
 			return;
 		}
-		memcpy(palette, TheScreen->format->palette->colors,
-			ncolors * sizeof(SDL_Color));
+		SDL_LockSurface(TheScreen);
+		memcpy(pixels, TheScreen->pixels, framesize);
+
+		if (TheScreen->format->palette) {
+			ncolors = TheScreen->format->palette->ncolors;
+			if (!(palette = new SDL_Color[ncolors])) {
+				delete[] pixels;
+				return;
+			}
+			memcpy(palette, TheScreen->format->palette->colors,
+				ncolors * sizeof(SDL_Color));
+		}
+		SDL_UnlockSurface(TheScreen);
 	}
-	SDL_UnlockSurface(TheScreen);
-#endif
 
 	TheScreen = SDL_SetVideoMode(w, h, bpp, flags ^ SDL_FULLSCREEN);
 	if (!TheScreen) {
 		TheScreen = SDL_SetVideoMode(w, h, bpp, flags);
 		if (!TheScreen) { // completely screwed.
-#ifndef USE_OPENGL
-			delete[] pixels;
-			delete[] palette;
-#endif
+			if (!UseOpenGL) {
+				delete[] pixels;
+				delete[] palette;
+			}
 			fprintf(stderr, "Toggle to fullscreen, crashed all\n");
 			Exit(-1);
 		}
@@ -894,20 +880,20 @@ void ToggleFullScreen(void)
 	SDL_ShowCursor(SDL_ENABLE);
 	SDL_ShowCursor(SDL_DISABLE);
 
-#ifdef USE_OPENGL
-	ReloadOpenGL();
-#else
-	SDL_LockSurface(TheScreen);
-	memcpy(TheScreen->pixels, pixels, framesize);
-	delete[] pixels;
+	if (UseOpenGL) {
+		ReloadOpenGL();
+	} else {
+		SDL_LockSurface(TheScreen);
+		memcpy(TheScreen->pixels, pixels, framesize);
+		delete[] pixels;
 
-	if (TheScreen->format->palette) {
-		// !!! FIXME : No idea if that flags param is right.
-		SDL_SetPalette(TheScreen, SDL_LOGPAL, palette, 0, ncolors);
-		delete[] palette;
+		if (TheScreen->format->palette) {
+			// !!! FIXME : No idea if that flags param is right.
+			SDL_SetPalette(TheScreen, SDL_LOGPAL, palette, 0, ncolors);
+			delete[] palette;
+		}
+		SDL_UnlockSurface(TheScreen);
 	}
-	SDL_UnlockSurface(TheScreen);
-#endif
 
 	SDL_SetClipRect(TheScreen, &clip);
 
