@@ -25,7 +25,7 @@
 --      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 --      02111-1307, USA.
 --
---      $Id: game.lua 9003 2007-07-08 02:21:01Z jim4 $
+--      $Id: game.lua 9072 2007-08-26 02:28:50Z jim4 $
 
 function BosGameMenu()
   local menu = MenuScreen()
@@ -82,7 +82,8 @@ function RunSaveMenu()
 
   local t = menu:addTextInputField("game.sav", 16, 40, 224)
 
-  local browser = menu:addBrowser("~save", ".sav.gz$", 16, 70, 224, 166)
+  local lister = CreateFilteringLister(".sav.gz$", ListFilesInDirectory)
+  local browser = menu:addBrowser("~save", lister, 16, 70, 224, 166)
   local function cb(s)
     t:setText(browser:getSelectedItem())
   end
